Documentation
¶
Overview ¶
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 with prefix 'a2'
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 with prefix 'a2'
Index ¶
- type AccountIdentification4Choice
- type BranchAndFinancialInstitutionIdentification5
- type BranchAndFinancialInstitutionIdentification5TCH
- type ClearingSystemMemberIdentification2
- type ClearingSystemMemberIdentification2TCH
- type DocumentTCH
- type FinancialInstitutionIdentification8
- type FinancialInstitutionIdentification8TCH
- type GenericAccountIdentification1
- type IdentificationAssignment2
- type IdentificationAssignment2TCH
- type IdentificationInformation2
- type IdentificationInformation2TCH
- type IdentificationModification2
- type IdentificationModification2TCH
- type IdentificationModificationAdviceV02
- type IdentificationModificationAdviceV02TCH
- type Max34Text
- type Max35Text
- type Max35TextTCH
- type Max140Text
- type OrigMsgName
- type OriginalTransactionReference18
- type OriginalTransactionReference18TCH
- type Party12Choice
- type Party12ChoiceTCH
- type PaymentIdentification4
- type PaymentIdentification4TCH
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountIdentification4Choice ¶
type AccountIdentification4Choice struct {
Othr *GenericAccountIdentification1 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Othr,omitempty"`
}
func (AccountIdentification4Choice) MarshalXML ¶
func (v AccountIdentification4Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (AccountIdentification4Choice) Validate ¶
func (v AccountIdentification4Choice) Validate() error
type BranchAndFinancialInstitutionIdentification5 ¶
type BranchAndFinancialInstitutionIdentification5 struct {
FinInstnId FinancialInstitutionIdentification8 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification5) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification5) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification5) Validate ¶
func (v BranchAndFinancialInstitutionIdentification5) Validate() error
type BranchAndFinancialInstitutionIdentification5TCH ¶
type BranchAndFinancialInstitutionIdentification5TCH struct {
FinInstnId FinancialInstitutionIdentification8TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification5TCH) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification5TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification5TCH) Validate ¶
func (v BranchAndFinancialInstitutionIdentification5TCH) Validate() error
type ClearingSystemMemberIdentification2 ¶
type ClearingSystemMemberIdentification2 struct {
MmbId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MmbId"`
}
func (ClearingSystemMemberIdentification2) MarshalXML ¶
func (v ClearingSystemMemberIdentification2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2) Validate ¶
func (v ClearingSystemMemberIdentification2) Validate() error
type ClearingSystemMemberIdentification2TCH ¶
type ClearingSystemMemberIdentification2TCH struct {
MmbId Max35TextTCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MmbId"`
}
func (ClearingSystemMemberIdentification2TCH) MarshalXML ¶
func (v ClearingSystemMemberIdentification2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2TCH) Validate ¶
func (v ClearingSystemMemberIdentification2TCH) Validate() error
type DocumentTCH ¶
type DocumentTCH struct {
XMLName xml.Name
IdModAdvc IdentificationModificationAdviceV02TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 IdModAdvc"`
}
func (DocumentTCH) MarshalXML ¶
func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (DocumentTCH) Validate ¶
func (v DocumentTCH) Validate() error
type FinancialInstitutionIdentification8 ¶
type FinancialInstitutionIdentification8 struct {
ClrSysMmbId ClearingSystemMemberIdentification2 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification8) MarshalXML ¶
func (v FinancialInstitutionIdentification8) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification8) Validate ¶
func (v FinancialInstitutionIdentification8) Validate() error
type FinancialInstitutionIdentification8TCH ¶
type FinancialInstitutionIdentification8TCH struct {
ClrSysMmbId ClearingSystemMemberIdentification2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification8TCH) MarshalXML ¶
func (v FinancialInstitutionIdentification8TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification8TCH) Validate ¶
func (v FinancialInstitutionIdentification8TCH) Validate() error
type GenericAccountIdentification1 ¶
type GenericAccountIdentification1 struct {
Id Max34Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Id"`
}
func (GenericAccountIdentification1) MarshalXML ¶
func (v GenericAccountIdentification1) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (GenericAccountIdentification1) Validate ¶
func (v GenericAccountIdentification1) Validate() error
type IdentificationAssignment2 ¶
type IdentificationAssignment2 struct {
MsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 CreDtTm"`
Assgnr Party12Choice `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Assgnr"`
Assgne Party12Choice `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Assgne"`
}
func (IdentificationAssignment2) MarshalXML ¶
func (v IdentificationAssignment2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationAssignment2) Validate ¶
func (v IdentificationAssignment2) Validate() error
type IdentificationAssignment2TCH ¶
type IdentificationAssignment2TCH struct {
MsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 CreDtTm"`
Assgnr Party12ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Assgnr"`
Assgne Party12ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Assgne"`
}
func (IdentificationAssignment2TCH) MarshalXML ¶
func (v IdentificationAssignment2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationAssignment2TCH) Validate ¶
func (v IdentificationAssignment2TCH) Validate() error
type IdentificationInformation2 ¶
type IdentificationInformation2 struct {
Acct AccountIdentification4Choice `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Acct"`
Agt BranchAndFinancialInstitutionIdentification5 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Agt"`
}
func (IdentificationInformation2) MarshalXML ¶
func (v IdentificationInformation2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationInformation2) Validate ¶
func (v IdentificationInformation2) Validate() error
type IdentificationInformation2TCH ¶
type IdentificationInformation2TCH struct {
Acct AccountIdentification4Choice `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Acct"`
Agt BranchAndFinancialInstitutionIdentification5TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Agt"`
}
func (IdentificationInformation2TCH) MarshalXML ¶
func (v IdentificationInformation2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationInformation2TCH) Validate ¶
func (v IdentificationInformation2TCH) Validate() error
type IdentificationModification2 ¶
type IdentificationModification2 struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Id"`
OrgnlPtyAndAcctId *IdentificationInformation2 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 OrgnlPtyAndAcctId,omitempty"`
UpdtdPtyAndAcctId IdentificationInformation2 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 UpdtdPtyAndAcctId"`
AddtlInf *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 AddtlInf,omitempty"`
}
func (IdentificationModification2) MarshalXML ¶
func (v IdentificationModification2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationModification2) Validate ¶
func (v IdentificationModification2) Validate() error
type IdentificationModification2TCH ¶
type IdentificationModification2TCH struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Id"`
OrgnlPtyAndAcctId *IdentificationInformation2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 OrgnlPtyAndAcctId,omitempty"`
UpdtdPtyAndAcctId IdentificationInformation2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 UpdtdPtyAndAcctId"`
AddtlInf *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 AddtlInf,omitempty"`
}
func (IdentificationModification2TCH) MarshalXML ¶
func (v IdentificationModification2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationModification2TCH) Validate ¶
func (v IdentificationModification2TCH) Validate() error
type IdentificationModificationAdviceV02 ¶
type IdentificationModificationAdviceV02 struct {
Assgnmt IdentificationAssignment2 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Assgnmt"`
OrgnlTxRef OriginalTransactionReference18 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 OrgnlTxRef"`
Mod IdentificationModification2 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Mod"`
}
func (IdentificationModificationAdviceV02) MarshalXML ¶
func (v IdentificationModificationAdviceV02) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationModificationAdviceV02) Validate ¶
func (v IdentificationModificationAdviceV02) Validate() error
type IdentificationModificationAdviceV02TCH ¶
type IdentificationModificationAdviceV02TCH struct {
Assgnmt IdentificationAssignment2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Assgnmt"`
OrgnlTxRef OriginalTransactionReference18TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 OrgnlTxRef"`
Mod IdentificationModification2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Mod"`
}
func (IdentificationModificationAdviceV02TCH) MarshalXML ¶
func (v IdentificationModificationAdviceV02TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (IdentificationModificationAdviceV02TCH) Validate ¶
func (v IdentificationModificationAdviceV02TCH) Validate() error
type Max35TextTCH ¶
type Max35TextTCH string
func (Max35TextTCH) Validate ¶
func (v Max35TextTCH) Validate() error
type Max140Text ¶
type Max140Text string
func (Max140Text) Validate ¶
func (v Max140Text) Validate() error
type OrigMsgName ¶
type OrigMsgName string
const OrigMsgNamePacs00800108 OrigMsgName = "pacs.008.001.08"
const OrigMsgNamePain01300107 OrigMsgName = "pain.013.001.07"
func (OrigMsgName) Validate ¶
func (v OrigMsgName) Validate() error
type OriginalTransactionReference18 ¶
type OriginalTransactionReference18 struct {
MsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MsgId"`
MsgNmId OrigMsgName `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MsgNmId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 CreDtTm"`
OrgnlTx PaymentIdentification4 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 OrgnlTx"`
}
func (OriginalTransactionReference18) MarshalXML ¶
func (v OriginalTransactionReference18) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (OriginalTransactionReference18) Validate ¶
func (v OriginalTransactionReference18) Validate() error
type OriginalTransactionReference18TCH ¶
type OriginalTransactionReference18TCH struct {
MsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MsgId"`
MsgNmId OrigMsgName `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 MsgNmId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 CreDtTm"`
OrgnlTx PaymentIdentification4TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 OrgnlTx"`
}
func (OriginalTransactionReference18TCH) MarshalXML ¶
func (v OriginalTransactionReference18TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (OriginalTransactionReference18TCH) Validate ¶
func (v OriginalTransactionReference18TCH) Validate() error
type Party12Choice ¶
type Party12Choice struct {
Agt *BranchAndFinancialInstitutionIdentification5 `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Agt,omitempty"`
}
func (Party12Choice) MarshalXML ¶
func (v Party12Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party12Choice) Validate ¶
func (v Party12Choice) Validate() error
type Party12ChoiceTCH ¶
type Party12ChoiceTCH struct {
Agt *BranchAndFinancialInstitutionIdentification5TCH `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 Agt,omitempty"`
}
func (Party12ChoiceTCH) MarshalXML ¶
func (v Party12ChoiceTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party12ChoiceTCH) Validate ¶
func (v Party12ChoiceTCH) Validate() error
type PaymentIdentification4 ¶
type PaymentIdentification4 struct {
InstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 InstrId"`
EndToEndId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 EndToEndId"`
TxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 TxId"`
}
func (PaymentIdentification4) MarshalXML ¶
func (v PaymentIdentification4) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PaymentIdentification4) Validate ¶
func (v PaymentIdentification4) Validate() error
type PaymentIdentification4TCH ¶
type PaymentIdentification4TCH struct {
InstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 InstrId"`
EndToEndId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 EndToEndId"`
TxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:acmt.022.001.02 TxId"`
}
func (PaymentIdentification4TCH) MarshalXML ¶
func (v PaymentIdentification4TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PaymentIdentification4TCH) Validate ¶
func (v PaymentIdentification4TCH) Validate() error