admi_004_001_02

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 with prefix 'ne'

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:admi.004.001.02

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 with prefix 'ne'

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DocumentTCH added in v0.8.0

type DocumentTCH struct {
	XMLName      xml.Name
	SysEvtNtfctn SystemEventNotificationV02TCH `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 SysEvtNtfctn"`
}

func (DocumentTCH) MarshalXML added in v0.8.0

func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DocumentTCH) Validate added in v0.8.0

func (v DocumentTCH) Validate() error

type Event2

type Event2 struct {
	EvtCd    Max4AlphaNumericText `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtCd"`
	EvtParam []Max35Text          `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtParam"`
	EvtDesc  *Max1000Text         `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtDesc,omitempty"`
	EvtTm    rtp.ISODateTime      `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtTm"`
}

func (Event2) MarshalXML added in v0.7.0

func (v Event2) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Event2) Validate added in v0.8.0

func (v Event2) Validate() error

type Event2TCH added in v0.8.0

type Event2TCH struct {
	EvtCd    Max4AlphaNumericText `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtCd"`
	EvtParam []Max35Text          `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtParam"`
	EvtDesc  *Max1000Text         `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtDesc,omitempty"`
	EvtTm    rtp.ISODateTime      `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtTm"`
}

func (Event2TCH) MarshalXML added in v0.8.0

func (v Event2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Event2TCH) Validate added in v0.8.0

func (v Event2TCH) Validate() error

type Max4AlphaNumericText

type Max4AlphaNumericText string

func (Max4AlphaNumericText) Validate added in v0.8.0

func (v Max4AlphaNumericText) Validate() error

type Max35Text

type Max35Text string

func (Max35Text) Validate added in v0.8.0

func (v Max35Text) Validate() error

type Max1000Text

type Max1000Text string

func (Max1000Text) Validate added in v0.8.0

func (v Max1000Text) Validate() error

type SystemEventNotificationV02

type SystemEventNotificationV02 struct {
	EvtInf Event2 `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtInf"`
}

func (SystemEventNotificationV02) MarshalXML added in v0.7.0

func (v SystemEventNotificationV02) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (SystemEventNotificationV02) Validate

func (v SystemEventNotificationV02) Validate() error

type SystemEventNotificationV02TCH added in v0.8.0

type SystemEventNotificationV02TCH struct {
	EvtInf Event2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:admi.004.001.02 EvtInf"`
}

func (SystemEventNotificationV02TCH) Code added in v0.8.0

func (SystemEventNotificationV02TCH) Description added in v0.8.0

func (s SystemEventNotificationV02TCH) Description() string

func (SystemEventNotificationV02TCH) MarshalXML added in v0.8.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (SystemEventNotificationV02TCH) Parameters added in v0.8.0

func (s SystemEventNotificationV02TCH) Parameters() []string

func (SystemEventNotificationV02TCH) Time added in v0.8.0

func (SystemEventNotificationV02TCH) Validate added in v0.8.0

func (v SystemEventNotificationV02TCH) Validate() error

Jump to