admn_007_001_01

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 with prefix 'ut'

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:ma:20022:tech:xsd:admn.007.001.01

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 with prefix 'ut'

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BranchAndFinancialInstitutionIdentification4ADMN

type BranchAndFinancialInstitutionIdentification4ADMN struct {
	FinInstnId FinancialInstitutionIdentification7ADMN `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 FinInstnId"`
}

func (BranchAndFinancialInstitutionIdentification4ADMN) MarshalXML

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (BranchAndFinancialInstitutionIdentification4ADMN) Validate

type ClearingSystemMemberIdentification2ADMN

type ClearingSystemMemberIdentification2ADMN struct {
	MmbId Min11Max11Text `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 MmbId"`
}

func (ClearingSystemMemberIdentification2ADMN) MarshalXML

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (ClearingSystemMemberIdentification2ADMN) Validate

type DatabaseReportInformation

type DatabaseReportInformation struct {
	RptCd    ReportCode                                       `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 RptCd"`
	InstrId  Max35Text                                        `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 InstrId"`
	InstgAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 InstgAgt"`
	InstdAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 InstdAgt"`
}

func (DatabaseReportInformation) MarshalXML

func (v DatabaseReportInformation) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DatabaseReportInformation) Validate

func (v DatabaseReportInformation) Validate() error

type DatabaseReportInformationTCH

type DatabaseReportInformationTCH struct {
	RptCd    ReportCodeTCH                                    `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 RptCd"`
	InstrId  Max35TextTCH2                                    `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 InstrId"`
	InstgAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 InstgAgt"`
	InstdAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 InstdAgt"`
}

func (DatabaseReportInformationTCH) MarshalXML

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DatabaseReportInformationTCH) Validate

func (v DatabaseReportInformationTCH) Validate() error

type DatabaseReportRequest

type DatabaseReportRequest struct {
	GrpHdr   GrpHdr                    `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 GrpHdr"`
	DBRptInf DatabaseReportInformation `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 DBRptInf"`
}

func (DatabaseReportRequest) MarshalXML

func (v DatabaseReportRequest) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DatabaseReportRequest) Validate

func (v DatabaseReportRequest) Validate() error

type DatabaseReportRequestTCH

type DatabaseReportRequestTCH struct {
	GrpHdr   GrpHdrTCH                    `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 GrpHdr"`
	DBRptInf DatabaseReportInformationTCH `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 DBRptInf"`
}

func (DatabaseReportRequestTCH) MarshalXML

func (v DatabaseReportRequestTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DatabaseReportRequestTCH) Validate

func (v DatabaseReportRequestTCH) Validate() error

type DocumentTCH

type DocumentTCH struct {
	XMLName  xml.Name
	DBRptReq DatabaseReportRequestTCH `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 DBRptReq"`
}

func (DocumentTCH) MarshalXML

func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DocumentTCH) Validate

func (v DocumentTCH) Validate() error

type FinancialInstitutionIdentification7ADMN

type FinancialInstitutionIdentification7ADMN struct {
	ClrSysMmbId ClearingSystemMemberIdentification2ADMN `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 ClrSysMmbId"`
}

func (FinancialInstitutionIdentification7ADMN) MarshalXML

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (FinancialInstitutionIdentification7ADMN) Validate

type GrpHdr

type GrpHdr struct {
	MsgId   Max35Text       `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 MsgId"`
	CreDtTm rtp.ISODateTime `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 CreDtTm"`
}

func (GrpHdr) MarshalXML

func (v GrpHdr) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (GrpHdr) Validate

func (v GrpHdr) Validate() error

type GrpHdrTCH

type GrpHdrTCH struct {
	MsgId   Max35TextTCH    `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 MsgId"`
	CreDtTm rtp.ISODateTime `xml:"urn:iso:std:ma:20022:tech:xsd:admn.007.001.01 CreDtTm"`
}

func (GrpHdrTCH) MarshalXML

func (v GrpHdrTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (GrpHdrTCH) Validate

func (v GrpHdrTCH) Validate() error

type Max35Text

type Max35Text string

func (Max35Text) Validate

func (v Max35Text) Validate() error

type Max35TextTCH

type Max35TextTCH string

func (Max35TextTCH) Validate

func (v Max35TextTCH) Validate() error

type Max35TextTCH2

type Max35TextTCH2 string

func (Max35TextTCH2) Validate

func (v Max35TextTCH2) Validate() error

type Min11Max11Text

type Min11Max11Text string

func (Min11Max11Text) Validate

func (v Min11Max11Text) Validate() error

type ReportCode

type ReportCode string
const ReportCodeAvlbty ReportCode = "AVLBTY"

func (ReportCode) Validate

func (v ReportCode) Validate() error

type ReportCodeTCH

type ReportCodeTCH string
const ReportCodeTCHAvlbty ReportCodeTCH = "AVLBTY"

func (ReportCodeTCH) Validate

func (v ReportCodeTCH) Validate() error

Jump to