camt_056_001_08

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 with prefix 'rt'

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:camt.056.001.08

Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 with prefix 'rt'

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ActiveOrHistoricCurrencyAndAmount

type ActiveOrHistoricCurrencyAndAmount struct {
	Value ActiveOrHistoricCurrencyAndAmountSimpleType `xml:",chardata"`
	Ccy   ActiveOrHistoricCurrencyCode                `xml:"Ccy,attr"`
}

func (ActiveOrHistoricCurrencyAndAmount) Validate added in v0.8.0

type ActiveOrHistoricCurrencyAndAmountSimpleType added in v0.7.0

type ActiveOrHistoricCurrencyAndAmountSimpleType rtp.Amount

func (ActiveOrHistoricCurrencyAndAmountSimpleType) MarshalText added in v0.7.0

type ActiveOrHistoricCurrencyCode

type ActiveOrHistoricCurrencyCode string
const ActiveOrHistoricCurrencyCodeUsd ActiveOrHistoricCurrencyCode = "USD"

func (ActiveOrHistoricCurrencyCode) Validate added in v0.8.0

func (v ActiveOrHistoricCurrencyCode) Validate() error

type BranchAndFinancialInstitutionIdentification6

type BranchAndFinancialInstitutionIdentification6 struct {
	FinInstnId FinancialInstitutionIdentification18 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 FinInstnId"`
}

func (BranchAndFinancialInstitutionIdentification6) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (BranchAndFinancialInstitutionIdentification6) Validate added in v0.8.0

type BranchAndFinancialInstitutionIdentification6TCH

type BranchAndFinancialInstitutionIdentification6TCH struct {
	FinInstnId FinancialInstitutionIdentification18TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 FinInstnId"`
}

func (BranchAndFinancialInstitutionIdentification6TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (BranchAndFinancialInstitutionIdentification6TCH) Validate added in v0.8.0

type CancellationReason33Choice

type CancellationReason33Choice struct {
	Cd    *ExternalCancellationReason1Code `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Cd,omitempty"`
	Prtry *Max35Text                       `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Prtry,omitempty"`
}

func (CancellationReason33Choice) MarshalXML added in v0.7.0

func (v CancellationReason33Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (CancellationReason33Choice) Validate added in v0.8.0

func (v CancellationReason33Choice) Validate() error

type CancellationReason33ChoiceTCH

type CancellationReason33ChoiceTCH struct {
	Cd    *ExternalCancellationReason1Code `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Cd,omitempty"`
	Prtry *Max35TextTCH3                   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Prtry,omitempty"`
}

func (CancellationReason33ChoiceTCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (CancellationReason33ChoiceTCH) Validate added in v0.8.0

func (v CancellationReason33ChoiceTCH) Validate() error

type Case5

type Case5 struct {
	Id    Max35Text     `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id"`
	Cretr Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Cretr"`
}

func (Case5) MarshalXML added in v0.7.0

func (v Case5) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Case5) Validate added in v0.8.0

func (v Case5) Validate() error

type Case5TCH

type Case5TCH struct {
	Id    Max35Text        `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id"`
	Cretr Party40ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Cretr"`
}

func (Case5TCH) MarshalXML added in v0.7.0

func (v Case5TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Case5TCH) Validate added in v0.8.0

func (v Case5TCH) Validate() error

type CaseAssignment5

type CaseAssignment5 struct {
	Id      Max35Text       `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id"`
	Assgnr  Party40Choice   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Assgnr"`
	Assgne  Party40Choice   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Assgne"`
	CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CreDtTm"`
}

func (CaseAssignment5) MarshalXML added in v0.7.0

func (v CaseAssignment5) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (CaseAssignment5) Validate added in v0.8.0

func (v CaseAssignment5) Validate() error

type CaseAssignment5TCH

type CaseAssignment5TCH struct {
	Id      Max35TextTCH     `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id"`
	Assgnr  Party40ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Assgnr"`
	Assgne  Party40ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Assgne"`
	CreDtTm rtp.ISODateTime  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CreDtTm"`
}

func (CaseAssignment5TCH) MarshalXML added in v0.7.0

func (v CaseAssignment5TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (CaseAssignment5TCH) Validate added in v0.8.0

func (v CaseAssignment5TCH) Validate() error

type ClearingSystemMemberIdentification2

type ClearingSystemMemberIdentification2 struct {
	MmbId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 MmbId"`
}

func (ClearingSystemMemberIdentification2) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (ClearingSystemMemberIdentification2) Validate added in v0.8.0

type ClearingSystemMemberIdentification2TCH

type ClearingSystemMemberIdentification2TCH struct {
	MmbId Max35TextTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 MmbId"`
}

func (ClearingSystemMemberIdentification2TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (ClearingSystemMemberIdentification2TCH) Validate added in v0.8.0

type Contact4

type Contact4 struct {
	PhneNb *PhoneNumber `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PhneNb,omitempty"`
}

func (Contact4) MarshalXML added in v0.7.0

func (v Contact4) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Contact4) Validate added in v0.8.0

func (v Contact4) Validate() error

type CountryCode

type CountryCode string
const CountryCodeAd CountryCode = "AD"
const CountryCodeAe CountryCode = "AE"
const CountryCodeAf CountryCode = "AF"
const CountryCodeAg CountryCode = "AG"
const CountryCodeAi CountryCode = "AI"
const CountryCodeAl CountryCode = "AL"
const CountryCodeAm CountryCode = "AM"
const CountryCodeAo CountryCode = "AO"
const CountryCodeAq CountryCode = "AQ"
const CountryCodeAr CountryCode = "AR"
const CountryCodeAs CountryCode = "AS"
const CountryCodeAt CountryCode = "AT"
const CountryCodeAu CountryCode = "AU"
const CountryCodeAw CountryCode = "AW"
const CountryCodeAx CountryCode = "AX"
const CountryCodeAz CountryCode = "AZ"
const CountryCodeBa CountryCode = "BA"
const CountryCodeBb CountryCode = "BB"
const CountryCodeBd CountryCode = "BD"
const CountryCodeBe CountryCode = "BE"
const CountryCodeBf CountryCode = "BF"
const CountryCodeBg CountryCode = "BG"
const CountryCodeBh CountryCode = "BH"
const CountryCodeBi CountryCode = "BI"
const CountryCodeBj CountryCode = "BJ"
const CountryCodeBl CountryCode = "BL"
const CountryCodeBm CountryCode = "BM"
const CountryCodeBn CountryCode = "BN"
const CountryCodeBo CountryCode = "BO"
const CountryCodeBq CountryCode = "BQ"
const CountryCodeBr CountryCode = "BR"
const CountryCodeBs CountryCode = "BS"
const CountryCodeBt CountryCode = "BT"
const CountryCodeBv CountryCode = "BV"
const CountryCodeBw CountryCode = "BW"
const CountryCodeBy CountryCode = "BY"
const CountryCodeBz CountryCode = "BZ"
const CountryCodeCa CountryCode = "CA"
const CountryCodeCc CountryCode = "CC"
const CountryCodeCd CountryCode = "CD"
const CountryCodeCf CountryCode = "CF"
const CountryCodeCg CountryCode = "CG"
const CountryCodeCh CountryCode = "CH"
const CountryCodeCi CountryCode = "CI"
const CountryCodeCk CountryCode = "CK"
const CountryCodeCl CountryCode = "CL"
const CountryCodeCm CountryCode = "CM"
const CountryCodeCn CountryCode = "CN"
const CountryCodeCo CountryCode = "CO"
const CountryCodeCr CountryCode = "CR"
const CountryCodeCu CountryCode = "CU"
const CountryCodeCv CountryCode = "CV"
const CountryCodeCw CountryCode = "CW"
const CountryCodeCx CountryCode = "CX"
const CountryCodeCy CountryCode = "CY"
const CountryCodeCz CountryCode = "CZ"
const CountryCodeDe CountryCode = "DE"
const CountryCodeDj CountryCode = "DJ"
const CountryCodeDk CountryCode = "DK"
const CountryCodeDm CountryCode = "DM"
const CountryCodeDo CountryCode = "DO"
const CountryCodeDz CountryCode = "DZ"
const CountryCodeEc CountryCode = "EC"
const CountryCodeEe CountryCode = "EE"
const CountryCodeEg CountryCode = "EG"
const CountryCodeEh CountryCode = "EH"
const CountryCodeEr CountryCode = "ER"
const CountryCodeEs CountryCode = "ES"
const CountryCodeEt CountryCode = "ET"
const CountryCodeFi CountryCode = "FI"
const CountryCodeFj CountryCode = "FJ"
const CountryCodeFk CountryCode = "FK"
const CountryCodeFm CountryCode = "FM"
const CountryCodeFo CountryCode = "FO"
const CountryCodeFr CountryCode = "FR"
const CountryCodeGa CountryCode = "GA"
const CountryCodeGb CountryCode = "GB"
const CountryCodeGd CountryCode = "GD"
const CountryCodeGe CountryCode = "GE"
const CountryCodeGf CountryCode = "GF"
const CountryCodeGg CountryCode = "GG"
const CountryCodeGh CountryCode = "GH"
const CountryCodeGi CountryCode = "GI"
const CountryCodeGl CountryCode = "GL"
const CountryCodeGm CountryCode = "GM"
const CountryCodeGn CountryCode = "GN"
const CountryCodeGp CountryCode = "GP"
const CountryCodeGq CountryCode = "GQ"
const CountryCodeGr CountryCode = "GR"
const CountryCodeGs CountryCode = "GS"
const CountryCodeGt CountryCode = "GT"
const CountryCodeGu CountryCode = "GU"
const CountryCodeGw CountryCode = "GW"
const CountryCodeGy CountryCode = "GY"
const CountryCodeHk CountryCode = "HK"
const CountryCodeHm CountryCode = "HM"
const CountryCodeHn CountryCode = "HN"
const CountryCodeHr CountryCode = "HR"
const CountryCodeHt CountryCode = "HT"
const CountryCodeHu CountryCode = "HU"
const CountryCodeId CountryCode = "ID"
const CountryCodeIe CountryCode = "IE"
const CountryCodeIl CountryCode = "IL"
const CountryCodeIm CountryCode = "IM"
const CountryCodeIn CountryCode = "IN"
const CountryCodeIo CountryCode = "IO"
const CountryCodeIq CountryCode = "IQ"
const CountryCodeIr CountryCode = "IR"
const CountryCodeIs CountryCode = "IS"
const CountryCodeIt CountryCode = "IT"
const CountryCodeJe CountryCode = "JE"
const CountryCodeJm CountryCode = "JM"
const CountryCodeJo CountryCode = "JO"
const CountryCodeJp CountryCode = "JP"
const CountryCodeKe CountryCode = "KE"
const CountryCodeKg CountryCode = "KG"
const CountryCodeKh CountryCode = "KH"
const CountryCodeKi CountryCode = "KI"
const CountryCodeKm CountryCode = "KM"
const CountryCodeKn CountryCode = "KN"
const CountryCodeKp CountryCode = "KP"
const CountryCodeKr CountryCode = "KR"
const CountryCodeKw CountryCode = "KW"
const CountryCodeKy CountryCode = "KY"
const CountryCodeKz CountryCode = "KZ"
const CountryCodeLa CountryCode = "LA"
const CountryCodeLb CountryCode = "LB"
const CountryCodeLc CountryCode = "LC"
const CountryCodeLi CountryCode = "LI"
const CountryCodeLk CountryCode = "LK"
const CountryCodeLr CountryCode = "LR"
const CountryCodeLs CountryCode = "LS"
const CountryCodeLt CountryCode = "LT"
const CountryCodeLu CountryCode = "LU"
const CountryCodeLv CountryCode = "LV"
const CountryCodeLy CountryCode = "LY"
const CountryCodeMa CountryCode = "MA"
const CountryCodeMc CountryCode = "MC"
const CountryCodeMd CountryCode = "MD"
const CountryCodeMe CountryCode = "ME"
const CountryCodeMf CountryCode = "MF"
const CountryCodeMg CountryCode = "MG"
const CountryCodeMh CountryCode = "MH"
const CountryCodeMk CountryCode = "MK"
const CountryCodeMl CountryCode = "ML"
const CountryCodeMm CountryCode = "MM"
const CountryCodeMn CountryCode = "MN"
const CountryCodeMo CountryCode = "MO"
const CountryCodeMp CountryCode = "MP"
const CountryCodeMq CountryCode = "MQ"
const CountryCodeMr CountryCode = "MR"
const CountryCodeMs CountryCode = "MS"
const CountryCodeMt CountryCode = "MT"
const CountryCodeMu CountryCode = "MU"
const CountryCodeMv CountryCode = "MV"
const CountryCodeMw CountryCode = "MW"
const CountryCodeMx CountryCode = "MX"
const CountryCodeMy CountryCode = "MY"
const CountryCodeMz CountryCode = "MZ"
const CountryCodeNa CountryCode = "NA"
const CountryCodeNc CountryCode = "NC"
const CountryCodeNe CountryCode = "NE"
const CountryCodeNf CountryCode = "NF"
const CountryCodeNg CountryCode = "NG"
const CountryCodeNi CountryCode = "NI"
const CountryCodeNl CountryCode = "NL"
const CountryCodeNo CountryCode = "NO"
const CountryCodeNp CountryCode = "NP"
const CountryCodeNr CountryCode = "NR"
const CountryCodeNu CountryCode = "NU"
const CountryCodeNz CountryCode = "NZ"
const CountryCodeOm CountryCode = "OM"
const CountryCodePa CountryCode = "PA"
const CountryCodePe CountryCode = "PE"
const CountryCodePf CountryCode = "PF"
const CountryCodePg CountryCode = "PG"
const CountryCodePh CountryCode = "PH"
const CountryCodePk CountryCode = "PK"
const CountryCodePl CountryCode = "PL"
const CountryCodePm CountryCode = "PM"
const CountryCodePn CountryCode = "PN"
const CountryCodePr CountryCode = "PR"
const CountryCodePs CountryCode = "PS"
const CountryCodePt CountryCode = "PT"
const CountryCodePw CountryCode = "PW"
const CountryCodePy CountryCode = "PY"
const CountryCodeQa CountryCode = "QA"
const CountryCodeRe CountryCode = "RE"
const CountryCodeRo CountryCode = "RO"
const CountryCodeRs CountryCode = "RS"
const CountryCodeRu CountryCode = "RU"
const CountryCodeRw CountryCode = "RW"
const CountryCodeSa CountryCode = "SA"
const CountryCodeSb CountryCode = "SB"
const CountryCodeSc CountryCode = "SC"
const CountryCodeSd CountryCode = "SD"
const CountryCodeSe CountryCode = "SE"
const CountryCodeSg CountryCode = "SG"
const CountryCodeSh CountryCode = "SH"
const CountryCodeSi CountryCode = "SI"
const CountryCodeSj CountryCode = "SJ"
const CountryCodeSk CountryCode = "SK"
const CountryCodeSl CountryCode = "SL"
const CountryCodeSm CountryCode = "SM"
const CountryCodeSn CountryCode = "SN"
const CountryCodeSo CountryCode = "SO"
const CountryCodeSr CountryCode = "SR"
const CountryCodeSs CountryCode = "SS"
const CountryCodeSt CountryCode = "ST"
const CountryCodeSv CountryCode = "SV"
const CountryCodeSx CountryCode = "SX"
const CountryCodeSy CountryCode = "SY"
const CountryCodeSz CountryCode = "SZ"
const CountryCodeTc CountryCode = "TC"
const CountryCodeTd CountryCode = "TD"
const CountryCodeTf CountryCode = "TF"
const CountryCodeTg CountryCode = "TG"
const CountryCodeTh CountryCode = "TH"
const CountryCodeTj CountryCode = "TJ"
const CountryCodeTk CountryCode = "TK"
const CountryCodeTl CountryCode = "TL"
const CountryCodeTm CountryCode = "TM"
const CountryCodeTn CountryCode = "TN"
const CountryCodeTo CountryCode = "TO"
const CountryCodeTr CountryCode = "TR"
const CountryCodeTt CountryCode = "TT"
const CountryCodeTv CountryCode = "TV"
const CountryCodeTw CountryCode = "TW"
const CountryCodeTz CountryCode = "TZ"
const CountryCodeUa CountryCode = "UA"
const CountryCodeUg CountryCode = "UG"
const CountryCodeUm CountryCode = "UM"
const CountryCodeUs CountryCode = "US"
const CountryCodeUy CountryCode = "UY"
const CountryCodeUz CountryCode = "UZ"
const CountryCodeVa CountryCode = "VA"
const CountryCodeVc CountryCode = "VC"
const CountryCodeVe CountryCode = "VE"
const CountryCodeVg CountryCode = "VG"
const CountryCodeVi CountryCode = "VI"
const CountryCodeVn CountryCode = "VN"
const CountryCodeVu CountryCode = "VU"
const CountryCodeWf CountryCode = "WF"
const CountryCodeWs CountryCode = "WS"
const CountryCodeYe CountryCode = "YE"
const CountryCodeYt CountryCode = "YT"
const CountryCodeZa CountryCode = "ZA"
const CountryCodeZm CountryCode = "ZM"
const CountryCodeZw CountryCode = "ZW"

func (CountryCode) Validate added in v0.8.0

func (v CountryCode) Validate() error

type DateAndPlaceOfBirth1

type DateAndPlaceOfBirth1 struct {
	BirthDt     rtp.ISODate `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 BirthDt"`
	CityOfBirth Max35Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CityOfBirth"`
	CtryOfBirth CountryCode `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CtryOfBirth"`
}

func (DateAndPlaceOfBirth1) MarshalXML added in v0.7.0

func (v DateAndPlaceOfBirth1) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DateAndPlaceOfBirth1) Validate added in v0.8.0

func (v DateAndPlaceOfBirth1) Validate() error

type DocumentTCH

type DocumentTCH struct {
	XMLName         xml.Name
	FIToFIPmtCxlReq FIToFIPaymentCancellationRequestV08TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 FIToFIPmtCxlReq"`
}

func (DocumentTCH) MarshalXML added in v0.7.0

func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (DocumentTCH) Validate added in v0.8.0

func (v DocumentTCH) Validate() error

type ExternalCancellationReason1Code

type ExternalCancellationReason1Code string
const ExternalCancellationReason1CodeAc03 ExternalCancellationReason1Code = "AC03"
const ExternalCancellationReason1CodeAm09 ExternalCancellationReason1Code = "AM09"
const ExternalCancellationReason1CodeCust ExternalCancellationReason1Code = "CUST"
const ExternalCancellationReason1CodeDs24 ExternalCancellationReason1Code = "DS24"
const ExternalCancellationReason1CodeDupl ExternalCancellationReason1Code = "DUPL"
const ExternalCancellationReason1CodeFrad ExternalCancellationReason1Code = "FRAD"
const ExternalCancellationReason1CodeFrtr ExternalCancellationReason1Code = "FRTR"
const ExternalCancellationReason1CodeTech ExternalCancellationReason1Code = "TECH"
const ExternalCancellationReason1CodeUpay ExternalCancellationReason1Code = "UPAY"

func (ExternalCancellationReason1Code) Validate added in v0.8.0

type FIToFIPaymentCancellationRequestV08

type FIToFIPaymentCancellationRequestV08 struct {
	Assgnmt CaseAssignment5         `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Assgnmt"`
	Case    Case5                   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Case"`
	Undrlyg UnderlyingTransaction23 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Undrlyg"`
}

func (FIToFIPaymentCancellationRequestV08) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (FIToFIPaymentCancellationRequestV08) Validate

type FIToFIPaymentCancellationRequestV08TCH

type FIToFIPaymentCancellationRequestV08TCH struct {
	Assgnmt CaseAssignment5TCH         `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Assgnmt"`
	Case    Case5TCH                   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Case"`
	Undrlyg UnderlyingTransaction23TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Undrlyg"`
}

func (FIToFIPaymentCancellationRequestV08TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (FIToFIPaymentCancellationRequestV08TCH) Validate added in v0.8.0

type FinancialInstitutionIdentification18

type FinancialInstitutionIdentification18 struct {
	ClrSysMmbId ClearingSystemMemberIdentification2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 ClrSysMmbId"`
}

func (FinancialInstitutionIdentification18) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (FinancialInstitutionIdentification18) Validate added in v0.8.0

type FinancialInstitutionIdentification18TCH

type FinancialInstitutionIdentification18TCH struct {
	ClrSysMmbId ClearingSystemMemberIdentification2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 ClrSysMmbId"`
}

func (FinancialInstitutionIdentification18TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (FinancialInstitutionIdentification18TCH) Validate added in v0.8.0

type GenericOrganisationIdentification1

type GenericOrganisationIdentification1 struct {
	Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id"`
}

func (GenericOrganisationIdentification1) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (GenericOrganisationIdentification1) Validate added in v0.8.0

type GenericOrganisationIdentification1TCH

type GenericOrganisationIdentification1TCH struct {
	Id Max35TextTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id"`
}

func (GenericOrganisationIdentification1TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (GenericOrganisationIdentification1TCH) Validate added in v0.8.0

type LEIIdentifier

type LEIIdentifier string

func (LEIIdentifier) Validate added in v0.8.0

func (v LEIIdentifier) Validate() error

type Max105Text

type Max105Text string

func (Max105Text) Validate added in v0.8.0

func (v Max105Text) Validate() error

type Max140Text

type Max140Text string

func (Max140Text) Validate added in v0.8.0

func (v Max140Text) Validate() error

type Max16Text

type Max16Text string

func (Max16Text) Validate added in v0.8.0

func (v Max16Text) Validate() error

type Max35Text

type Max35Text string

func (Max35Text) Validate added in v0.8.0

func (v Max35Text) Validate() error

type Max35TextTCH

type Max35TextTCH string

func (Max35TextTCH) Validate added in v0.8.0

func (v Max35TextTCH) Validate() error

type Max35TextTCH2

type Max35TextTCH2 string

func (Max35TextTCH2) Validate added in v0.8.0

func (v Max35TextTCH2) Validate() error

type Max35TextTCH3

type Max35TextTCH3 string
const Max35TextTCH3Wiam Max35TextTCH3 = "WIAM"
const Max35TextTCH3Wict Max35TextTCH3 = "WICT"
const Max35TextTCH3Widp Max35TextTCH3 = "WIDP"
const Max35TextTCH3Wifd Max35TextTCH3 = "WIFD"
const Max35TextTCH3Wift Max35TextTCH3 = "WIFT"
const Max35TextTCH3With Max35TextTCH3 = "WITH"

func (Max35TextTCH3) Validate added in v0.8.0

func (v Max35TextTCH3) Validate() error

type Max70Text

type Max70Text string

func (Max70Text) Validate added in v0.8.0

func (v Max70Text) Validate() error

type OrganisationIdentification29

type OrganisationIdentification29 struct {
	LEI  *LEIIdentifier                      `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 LEI,omitempty"`
	Othr *GenericOrganisationIdentification1 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Othr,omitempty"`
}

func (OrganisationIdentification29) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (OrganisationIdentification29) Validate added in v0.8.0

func (v OrganisationIdentification29) Validate() error

type OrganisationIdentification29TCH

type OrganisationIdentification29TCH struct {
	Othr GenericOrganisationIdentification1TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Othr"`
}

func (OrganisationIdentification29TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (OrganisationIdentification29TCH) Validate added in v0.8.0

type OrganisationIdentification29TCH2

type OrganisationIdentification29TCH2 struct {
	LEI LEIIdentifier `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 LEI"`
}

func (OrganisationIdentification29TCH2) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (OrganisationIdentification29TCH2) Validate added in v0.8.0

type OrigMsgName

type OrigMsgName string
const OrigMsgNamePacs00800106 OrigMsgName = "pacs.008.001.06"
const OrigMsgNamePacs00800108 OrigMsgName = "pacs.008.001.08"
const OrigMsgNamePacs00900108 OrigMsgName = "pacs.009.001.08"
const OrigMsgNamePain01300107 OrigMsgName = "pain.013.001.07"

func (OrigMsgName) Validate added in v0.8.0

func (v OrigMsgName) Validate() error

type OriginalGroupHeader15

type OriginalGroupHeader15 struct {
	OrgnlMsgId   Max35Text        `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlMsgId"`
	OrgnlMsgNmId OrigMsgName      `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlMsgNmId"`
	OrgnlCreDtTm *rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlCreDtTm,omitempty"`
}

func (OriginalGroupHeader15) MarshalXML added in v0.7.0

func (v OriginalGroupHeader15) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (OriginalGroupHeader15) Validate added in v0.8.0

func (v OriginalGroupHeader15) Validate() error

type OriginalTransactionReference28

type OriginalTransactionReference28 struct {
	Dbtr *Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Dbtr,omitempty"`
	Cdtr *Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Cdtr,omitempty"`
}

func (OriginalTransactionReference28) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (OriginalTransactionReference28) Validate added in v0.8.0

type OriginalTransactionReference28TCH

type OriginalTransactionReference28TCH struct {
	Dbtr *Party40ChoiceTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Dbtr,omitempty"`
	Cdtr *Party40ChoiceTCH3 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Cdtr,omitempty"`
}

func (OriginalTransactionReference28TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (OriginalTransactionReference28TCH) Validate added in v0.8.0

type Party38Choice

type Party38Choice struct {
	OrgId  *OrganisationIdentification29 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgId,omitempty"`
	PrvtId *PersonIdentification13       `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PrvtId,omitempty"`
}

func (Party38Choice) MarshalXML added in v0.7.0

func (v Party38Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Party38Choice) Validate added in v0.8.0

func (v Party38Choice) Validate() error

type Party38ChoiceTCH

type Party38ChoiceTCH struct {
	OrgId *OrganisationIdentification29TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgId,omitempty"`
}

func (Party38ChoiceTCH) MarshalXML added in v0.7.0

func (v Party38ChoiceTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Party38ChoiceTCH) Validate added in v0.8.0

func (v Party38ChoiceTCH) Validate() error

type Party38ChoiceTCH2

type Party38ChoiceTCH2 struct {
	OrgId  *OrganisationIdentification29TCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgId,omitempty"`
	PrvtId *PersonIdentification13TCH        `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PrvtId,omitempty"`
}

func (Party38ChoiceTCH2) MarshalXML added in v0.7.0

func (v Party38ChoiceTCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Party38ChoiceTCH2) Validate added in v0.8.0

func (v Party38ChoiceTCH2) Validate() error

type Party40Choice

type Party40Choice struct {
	Pty *PartyIdentification135                       `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Pty,omitempty"`
	Agt *BranchAndFinancialInstitutionIdentification6 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Agt,omitempty"`
}

func (Party40Choice) MarshalXML added in v0.7.0

func (v Party40Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Party40Choice) Validate added in v0.8.0

func (v Party40Choice) Validate() error

type Party40ChoiceTCH

type Party40ChoiceTCH struct {
	Agt *BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Agt,omitempty"`
}

func (Party40ChoiceTCH) MarshalXML added in v0.7.0

func (v Party40ChoiceTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Party40ChoiceTCH) Validate added in v0.8.0

func (v Party40ChoiceTCH) Validate() error

type Party40ChoiceTCH2

type Party40ChoiceTCH2 struct {
	Pty *PartyIdentification135TCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Pty,omitempty"`
}

func (Party40ChoiceTCH2) MarshalXML added in v0.7.0

func (v Party40ChoiceTCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Party40ChoiceTCH2) Validate added in v0.8.0

func (v Party40ChoiceTCH2) Validate() error

type Party40ChoiceTCH3

type Party40ChoiceTCH3 struct {
	Pty *PartyIdentification135TCH3 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Pty,omitempty"`
}

func (Party40ChoiceTCH3) MarshalXML added in v0.7.0

func (v Party40ChoiceTCH3) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (Party40ChoiceTCH3) Validate added in v0.8.0

func (v Party40ChoiceTCH3) Validate() error

type PartyIdentification135

type PartyIdentification135 struct {
	Nm       *Max140Text      `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Nm,omitempty"`
	PstlAdr  *PostalAddress24 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PstlAdr,omitempty"`
	Id       *Party38Choice   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id,omitempty"`
	CtctDtls *Contact4        `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CtctDtls,omitempty"`
}

func (PartyIdentification135) MarshalXML added in v0.7.0

func (v PartyIdentification135) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PartyIdentification135) Validate added in v0.8.0

func (v PartyIdentification135) Validate() error

type PartyIdentification135TCH

type PartyIdentification135TCH struct {
	Nm *Max140Text       `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Nm,omitempty"`
	Id *Party38ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id,omitempty"`
}

func (PartyIdentification135TCH) MarshalXML added in v0.7.0

func (v PartyIdentification135TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PartyIdentification135TCH) Validate added in v0.8.0

func (v PartyIdentification135TCH) Validate() error

type PartyIdentification135TCH2

type PartyIdentification135TCH2 struct {
	Nm      Max140Text          `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Nm"`
	PstlAdr *PostalAddress24TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PstlAdr,omitempty"`
	Id      *Party38ChoiceTCH2  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id,omitempty"`
}

func (PartyIdentification135TCH2) MarshalXML added in v0.7.0

func (v PartyIdentification135TCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PartyIdentification135TCH2) Validate added in v0.8.0

func (v PartyIdentification135TCH2) Validate() error

type PartyIdentification135TCH3

type PartyIdentification135TCH3 struct {
	Nm       Max140Text          `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Nm"`
	PstlAdr  *PostalAddress24TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PstlAdr,omitempty"`
	Id       *Party38ChoiceTCH2  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Id,omitempty"`
	CtctDtls *Contact4           `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CtctDtls,omitempty"`
}

func (PartyIdentification135TCH3) MarshalXML added in v0.7.0

func (v PartyIdentification135TCH3) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PartyIdentification135TCH3) Validate added in v0.8.0

func (v PartyIdentification135TCH3) Validate() error

type PaymentCancellationReason5

type PaymentCancellationReason5 struct {
	Orgtr    *PartyIdentification135    `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Orgtr,omitempty"`
	Rsn      CancellationReason33Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Rsn"`
	AddtlInf *Max105Text                `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 AddtlInf,omitempty"`
}

func (PaymentCancellationReason5) MarshalXML added in v0.7.0

func (v PaymentCancellationReason5) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PaymentCancellationReason5) Validate added in v0.8.0

func (v PaymentCancellationReason5) Validate() error

type PaymentCancellationReason5TCH

type PaymentCancellationReason5TCH struct {
	Orgtr    *PartyIdentification135TCH    `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Orgtr,omitempty"`
	Rsn      CancellationReason33ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Rsn"`
	AddtlInf *Max105Text                   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 AddtlInf,omitempty"`
}

func (PaymentCancellationReason5TCH) MarshalXML added in v0.7.0

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PaymentCancellationReason5TCH) Validate added in v0.8.0

func (v PaymentCancellationReason5TCH) Validate() error

type PaymentTransaction106

type PaymentTransaction106 struct {
	OrgnlInstrId        Max35Text                         `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlInstrId"`
	OrgnlEndToEndId     *Max35Text                        `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlEndToEndId,omitempty"`
	OrgnlTxId           Max35Text                         `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlTxId"`
	OrgnlUETR           *UUIDv4Identifier                 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlUETR,omitempty"`
	OrgnlClrSysRef      Max35Text                         `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlClrSysRef"`
	OrgnlIntrBkSttlmAmt ActiveOrHistoricCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlIntrBkSttlmAmt"`
	OrgnlIntrBkSttlmDt  rtp.ISODate                       `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlIntrBkSttlmDt"`
	CxlRsnInf           PaymentCancellationReason5        `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CxlRsnInf"`
	OrgnlTxRef          *OriginalTransactionReference28   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlTxRef,omitempty"`
}

func (PaymentTransaction106) MarshalXML added in v0.7.0

func (v PaymentTransaction106) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PaymentTransaction106) Validate added in v0.8.0

func (v PaymentTransaction106) Validate() error

type PaymentTransaction106TCH

type PaymentTransaction106TCH struct {
	OrgnlInstrId        Max35Text                          `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlInstrId"`
	OrgnlEndToEndId     *Max35Text                         `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlEndToEndId,omitempty"`
	OrgnlTxId           Max35Text                          `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlTxId"`
	OrgnlUETR           *UUIDv4Identifier                  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlUETR,omitempty"`
	OrgnlClrSysRef      Max35Text                          `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlClrSysRef"`
	OrgnlIntrBkSttlmAmt ActiveOrHistoricCurrencyAndAmount  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlIntrBkSttlmAmt"`
	OrgnlIntrBkSttlmDt  rtp.ISODate                        `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlIntrBkSttlmDt"`
	CxlRsnInf           PaymentCancellationReason5TCH      `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CxlRsnInf"`
	OrgnlTxRef          *OriginalTransactionReference28TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlTxRef,omitempty"`
}

func (PaymentTransaction106TCH) MarshalXML added in v0.7.0

func (v PaymentTransaction106TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PaymentTransaction106TCH) Validate added in v0.8.0

func (v PaymentTransaction106TCH) Validate() error

type PersonIdentification13

type PersonIdentification13 struct {
	DtAndPlcOfBirth DateAndPlaceOfBirth1 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 DtAndPlcOfBirth"`
}

func (PersonIdentification13) MarshalXML added in v0.7.0

func (v PersonIdentification13) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PersonIdentification13) Validate added in v0.8.0

func (v PersonIdentification13) Validate() error

type PersonIdentification13TCH

type PersonIdentification13TCH struct {
	DtAndPlcOfBirth DateAndPlaceOfBirth1 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 DtAndPlcOfBirth"`
}

func (PersonIdentification13TCH) MarshalXML added in v0.7.0

func (v PersonIdentification13TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PersonIdentification13TCH) Validate added in v0.8.0

func (v PersonIdentification13TCH) Validate() error

type PhoneNumber

type PhoneNumber string

func (PhoneNumber) Validate added in v0.8.0

func (v PhoneNumber) Validate() error

type PostalAddress24

type PostalAddress24 struct {
	StrtNm      Max70Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 StrtNm"`
	BldgNb      *Max16Text  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 BldgNb,omitempty"`
	PstCd       Max16Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PstCd"`
	TwnNm       Max35Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 TwnNm"`
	CtrySubDvsn Max35Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CtrySubDvsn"`
	Ctry        CountryCode `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Ctry"`
	AdrLine     *Max70Text  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 AdrLine,omitempty"`
}

func (PostalAddress24) MarshalXML added in v0.7.0

func (v PostalAddress24) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PostalAddress24) Validate added in v0.8.0

func (v PostalAddress24) Validate() error

type PostalAddress24TCH

type PostalAddress24TCH struct {
	StrtNm      Max70Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 StrtNm"`
	BldgNb      *Max16Text  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 BldgNb,omitempty"`
	PstCd       Max16Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 PstCd"`
	TwnNm       Max35Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 TwnNm"`
	CtrySubDvsn Max35Text   `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 CtrySubDvsn"`
	Ctry        CountryCode `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 Ctry"`
	AdrLine     *Max70Text  `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 AdrLine,omitempty"`
}

func (PostalAddress24TCH) MarshalXML added in v0.7.0

func (v PostalAddress24TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (PostalAddress24TCH) Validate added in v0.8.0

func (v PostalAddress24TCH) Validate() error

type UUIDv4Identifier

type UUIDv4Identifier string

func (UUIDv4Identifier) Validate added in v0.8.0

func (v UUIDv4Identifier) Validate() error

type UnderlyingTransaction23

type UnderlyingTransaction23 struct {
	OrgnlGrpInfAndCxl OriginalGroupHeader15 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlGrpInfAndCxl"`
	TxInf             PaymentTransaction106 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 TxInf"`
}

func (UnderlyingTransaction23) MarshalXML added in v0.7.0

func (v UnderlyingTransaction23) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (UnderlyingTransaction23) Validate added in v0.8.0

func (v UnderlyingTransaction23) Validate() error

type UnderlyingTransaction23TCH

type UnderlyingTransaction23TCH struct {
	OrgnlGrpInfAndCxl OriginalGroupHeader15    `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 OrgnlGrpInfAndCxl"`
	TxInf             PaymentTransaction106TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.056.001.08 TxInf"`
}

func (UnderlyingTransaction23TCH) MarshalXML added in v0.7.0

func (v UnderlyingTransaction23TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error

MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix

func (UnderlyingTransaction23TCH) Validate added in v0.8.0

func (v UnderlyingTransaction23TCH) Validate() error

Jump to