Documentation
¶
Overview ¶
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for http://www.w3.org/2000/09/xmldsig# with prefix 'ds'
Index ¶
- type CanonicalizationMethodType
- type CryptoBinary
- type DSAKeyValueType
- type DigestMethodType
- type DigestValueType
- type HMACOutputLengthType
- type KeyInfoType
- type KeyValueType
- type ManifestType
- type ObjectType
- type PGPDataType
- type RSAKeyValueType
- type ReferenceType
- type RetrievalMethodType
- type SPKIDataType
- type Signature
- type SignatureMethodType
- type SignaturePropertiesType
- type SignaturePropertyType
- type SignatureValueType
- type SignedInfoType
- type TransformType
- type TransformsType
- type X509DataType
- type X509IssuerSerialType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CryptoBinary ¶
type CryptoBinary string
type DSAKeyValueType ¶
type DSAKeyValueType struct {
G *CryptoBinary `xml:"G,omitempty"`
Y CryptoBinary `xml:"Y"`
J *CryptoBinary `xml:"J,omitempty"`
}
func (DSAKeyValueType) MarshalXML ¶
func (v DSAKeyValueType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type DigestMethodType ¶
type DigestValueType ¶
type DigestValueType string
type HMACOutputLengthType ¶
type HMACOutputLengthType int64
type KeyInfoType ¶
type KeyInfoType struct {
Id *string `xml:"Id,attr,omitempty"`
KeyName []*string `xml:"KeyName,omitempty"`
KeyValue []*KeyValueType `xml:"KeyValue,omitempty"`
RetrievalMethod []*RetrievalMethodType `xml:"RetrievalMethod,omitempty"`
X509Data []*X509DataType `xml:"X509Data,omitempty"`
PGPData []*PGPDataType `xml:"PGPData,omitempty"`
SPKIData []*SPKIDataType `xml:"SPKIData,omitempty"`
MgmtData []*string `xml:"MgmtData,omitempty"`
}
func (KeyInfoType) MarshalXML ¶
func (v KeyInfoType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type KeyValueType ¶
type KeyValueType struct {
DSAKeyValue *DSAKeyValueType `xml:"DSAKeyValue,omitempty"`
RSAKeyValue *RSAKeyValueType `xml:"RSAKeyValue,omitempty"`
}
func (KeyValueType) MarshalXML ¶
func (v KeyValueType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type ManifestType ¶
type ManifestType struct {
Id *string `xml:"Id,attr,omitempty"`
Reference []ReferenceType `xml:"Reference"`
}
func (ManifestType) MarshalXML ¶
func (v ManifestType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type ObjectType ¶
type PGPDataType ¶
type PGPDataType struct {
PGPKeyID *string `xml:"PGPKeyID,omitempty"`
PGPKeyPacket *string `xml:"PGPKeyPacket,omitempty"`
}
func (PGPDataType) MarshalXML ¶
func (v PGPDataType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type RSAKeyValueType ¶
type RSAKeyValueType struct {
Modulus CryptoBinary `xml:"Modulus"`
Exponent CryptoBinary `xml:"Exponent"`
}
func (RSAKeyValueType) MarshalXML ¶
func (v RSAKeyValueType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type ReferenceType ¶
type ReferenceType struct {
Id *string `xml:"Id,attr,omitempty"`
URI *string `xml:"URI,attr,omitempty"`
Type *string `xml:"Type,attr,omitempty"`
Transforms *TransformsType `xml:"Transforms,omitempty"`
DigestMethod DigestMethodType `xml:"DigestMethod"`
DigestValue DigestValueType `xml:"DigestValue"`
}
func (ReferenceType) MarshalXML ¶
func (v ReferenceType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type RetrievalMethodType ¶
type RetrievalMethodType struct {
URI string `xml:"URI,attr"`
Type *string `xml:"Type,attr,omitempty"`
Transforms *TransformsType `xml:"Transforms,omitempty"`
}
func (RetrievalMethodType) MarshalXML ¶
func (v RetrievalMethodType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type SPKIDataType ¶
func (SPKIDataType) MarshalXML ¶
func (v SPKIDataType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type Signature ¶
type Signature struct {
Xmlns []xml.Attr `xml:",attr"`
Id *string `xml:"Id,attr,omitempty"`
SignedInfo SignedInfoType `xml:"SignedInfo"`
SignatureValue SignatureValueType `xml:"SignatureValue"`
KeyInfo *KeyInfoType `xml:"KeyInfo,omitempty"`
Object []*ObjectType `xml:"Object,omitempty"`
}
func (Signature) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (*Signature) UnmarshalXML ¶
UnmarshalXML is a custom unmarshaller that allows us to capture the xmlns attributes
type SignatureMethodType ¶
type SignatureMethodType struct {
Algorithm string `xml:"Algorithm,attr"`
HMACOutputLength *HMACOutputLengthType `xml:"HMACOutputLength,omitempty"`
Item *string `xml:",any,omitempty"`
}
func (SignatureMethodType) MarshalXML ¶
func (v SignatureMethodType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type SignaturePropertiesType ¶
type SignaturePropertiesType struct {
Id *string `xml:"Id,attr,omitempty"`
SignatureProperty []SignaturePropertyType `xml:"SignatureProperty"`
}
func (SignaturePropertiesType) MarshalXML ¶
func (v SignaturePropertiesType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type SignaturePropertyType ¶
type SignatureValueType ¶
type SignedInfoType ¶
type SignedInfoType struct {
Id *string `xml:"Id,attr,omitempty"`
CanonicalizationMethod CanonicalizationMethodType `xml:"CanonicalizationMethod"`
SignatureMethod SignatureMethodType `xml:"SignatureMethod"`
Reference []ReferenceType `xml:"Reference"`
}
func (SignedInfoType) MarshalXML ¶
func (v SignedInfoType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type TransformType ¶
type TransformType struct {
Algorithm string `xml:"Algorithm,attr"`
XPath []*string `xml:"XPath,omitempty"`
}
func (TransformType) MarshalXML ¶
func (v TransformType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type TransformsType ¶
type TransformsType struct {
Transform []TransformType `xml:"Transform"`
}
func (TransformsType) MarshalXML ¶
func (v TransformsType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type X509DataType ¶
type X509DataType struct {
X509IssuerSerial *X509IssuerSerialType `xml:"X509IssuerSerial,omitempty"`
X509SKI *string `xml:"X509SKI,omitempty"`
X509SubjectName *string `xml:"X509SubjectName,omitempty"`
X509Certificate *string `xml:"X509Certificate,omitempty"`
X509CRL *string `xml:"X509CRL,omitempty"`
}
func (X509DataType) MarshalXML ¶
func (v X509DataType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type X509IssuerSerialType ¶
type X509IssuerSerialType struct {
X509IssuerName string `xml:"X509IssuerName"`
X509SerialNumber string `xml:"X509SerialNumber"`
}
func (X509IssuerSerialType) MarshalXML ¶
func (v X509IssuerSerialType) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix