Documentation
¶
Overview ¶
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 with prefix 'fr'
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:admn.003.001.01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 with prefix 'fr'
Index ¶
- type BranchAndFinancialInstitutionIdentification4ADMN
- type ClearingSystemMemberIdentification2ADMN
- type DocumentTCH
- type FinancialInstitutionIdentification7ADMN
- type GrpHdr
- type GrpHdrTCH
- type Max35Text
- type Max35TextTCH
- type Max35TextTCH2
- type Min11Max11Text
- type SignOffReq
- type SignOffReqTCH
- type SignOffRequest
- type SignOffRequestTCH
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BranchAndFinancialInstitutionIdentification4ADMN ¶
type BranchAndFinancialInstitutionIdentification4ADMN struct {
FinInstnId FinancialInstitutionIdentification7ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification4ADMN) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification4ADMN) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification4ADMN) Validate ¶ added in v0.8.0
func (v BranchAndFinancialInstitutionIdentification4ADMN) Validate() error
type ClearingSystemMemberIdentification2ADMN ¶
type ClearingSystemMemberIdentification2ADMN struct {
MmbId Min11Max11Text `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 MmbId"`
}
func (ClearingSystemMemberIdentification2ADMN) MarshalXML ¶
func (v ClearingSystemMemberIdentification2ADMN) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2ADMN) Validate ¶ added in v0.8.0
func (v ClearingSystemMemberIdentification2ADMN) Validate() error
type DocumentTCH ¶
type DocumentTCH struct {
XMLName xml.Name
AdmnSignOffReq SignOffRequestTCH `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 AdmnSignOffReq"`
}
func (DocumentTCH) MarshalXML ¶
func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (DocumentTCH) Validate ¶ added in v0.8.0
func (v DocumentTCH) Validate() error
type FinancialInstitutionIdentification7ADMN ¶
type FinancialInstitutionIdentification7ADMN struct {
ClrSysMmbId ClearingSystemMemberIdentification2ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification7ADMN) MarshalXML ¶
func (v FinancialInstitutionIdentification7ADMN) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification7ADMN) Validate ¶ added in v0.8.0
func (v FinancialInstitutionIdentification7ADMN) Validate() error
type GrpHdr ¶
type GrpHdr struct {
MsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 CreDtTm"`
}
func (GrpHdr) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type GrpHdrTCH ¶
type GrpHdrTCH struct {
MsgId Max35TextTCH `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 CreDtTm"`
}
func (GrpHdrTCH) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type Max35TextTCH ¶
type Max35TextTCH string
func (Max35TextTCH) Validate ¶ added in v0.8.0
func (v Max35TextTCH) Validate() error
type Max35TextTCH2 ¶
type Max35TextTCH2 string
func (Max35TextTCH2) Validate ¶ added in v0.8.0
func (v Max35TextTCH2) Validate() error
type Min11Max11Text ¶
type Min11Max11Text string
func (Min11Max11Text) Validate ¶ added in v0.8.0
func (v Min11Max11Text) Validate() error
type SignOffReq ¶
type SignOffReq struct {
InstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 InstrId"`
InstgAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 InstgAgt"`
InstdAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 InstdAgt"`
}
func (SignOffReq) MarshalXML ¶
func (v SignOffReq) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (SignOffReq) Validate ¶ added in v0.8.0
func (v SignOffReq) Validate() error
type SignOffReqTCH ¶
type SignOffReqTCH struct {
InstrId Max35TextTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 InstrId"`
InstgAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 InstgAgt"`
InstdAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 InstdAgt"`
}
func (SignOffReqTCH) MarshalXML ¶
func (v SignOffReqTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (SignOffReqTCH) Validate ¶ added in v0.8.0
func (v SignOffReqTCH) Validate() error
type SignOffRequest ¶
type SignOffRequest struct {
GrpHdr GrpHdr `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 GrpHdr"`
SignOffReq SignOffReq `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 SignOffReq"`
}
func (SignOffRequest) MarshalXML ¶
func (v SignOffRequest) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (SignOffRequest) Validate ¶ added in v0.8.0
func (v SignOffRequest) Validate() error
type SignOffRequestTCH ¶
type SignOffRequestTCH struct {
GrpHdr GrpHdrTCH `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 GrpHdr"`
SignOffReq SignOffReqTCH `xml:"urn:iso:std:iso:20022:tech:xsd:admn.003.001.01 SignOffReq"`
}
func (SignOffRequestTCH) MarshalXML ¶
func (v SignOffRequestTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (SignOffRequestTCH) Validate ¶ added in v0.8.0
func (v SignOffRequestTCH) Validate() error