Documentation
¶
Overview ¶
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 with prefix 're'
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:admn.006.001.01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 with prefix 're'
Index ¶
- type BranchAndFinancialInstitutionIdentification4ADMN
- type ClearingSystemMemberIdentification2ADMN
- type DocumentTCH
- type EchoCode
- type EchoResp
- type EchoResponse
- type EchoResponseTCH
- type FinancialInstitutionIdentification7ADMN
- type GrpHdr
- type GrpHdrTCH
- type Max35Text
- type Max35TextTCH
- type Min11Max11Text
- type TransactionIndividualStatus3CodeEcho
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BranchAndFinancialInstitutionIdentification4ADMN ¶
type BranchAndFinancialInstitutionIdentification4ADMN struct {
FinInstnId FinancialInstitutionIdentification7ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification4ADMN) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification4ADMN) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification4ADMN) Validate ¶ added in v0.8.0
func (v BranchAndFinancialInstitutionIdentification4ADMN) Validate() error
type ClearingSystemMemberIdentification2ADMN ¶
type ClearingSystemMemberIdentification2ADMN struct {
MmbId Min11Max11Text `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 MmbId"`
}
func (ClearingSystemMemberIdentification2ADMN) MarshalXML ¶
func (v ClearingSystemMemberIdentification2ADMN) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2ADMN) Validate ¶ added in v0.8.0
func (v ClearingSystemMemberIdentification2ADMN) Validate() error
type DocumentTCH ¶
type DocumentTCH struct {
XMLName xml.Name
AdmnEchoResp EchoResponseTCH `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 AdmnEchoResp"`
}
func (DocumentTCH) MarshalXML ¶
func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (DocumentTCH) Validate ¶ added in v0.8.0
func (v DocumentTCH) Validate() error
type EchoResp ¶
type EchoResp struct {
InstgAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 InstgAgt"`
InstdAgt BranchAndFinancialInstitutionIdentification4ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 InstdAgt"`
OrgnlInstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 OrgnlInstrId"`
FnctnCd EchoCode `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 FnctnCd"`
TxSts TransactionIndividualStatus3CodeEcho `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 TxSts"`
}
func (EchoResp) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type EchoResponse ¶
type EchoResponse struct {
GrpHdr GrpHdr `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 GrpHdr"`
EchoResponse EchoResp `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 EchoResponse"`
}
func (EchoResponse) MarshalXML ¶
func (v EchoResponse) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (EchoResponse) Validate ¶ added in v0.8.0
func (v EchoResponse) Validate() error
type EchoResponseTCH ¶
type EchoResponseTCH struct {
GrpHdr GrpHdrTCH `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 GrpHdr"`
EchoResponse EchoResp `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 EchoResponse"`
}
func (EchoResponseTCH) MarshalXML ¶
func (v EchoResponseTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (EchoResponseTCH) Validate ¶ added in v0.8.0
func (v EchoResponseTCH) Validate() error
type FinancialInstitutionIdentification7ADMN ¶
type FinancialInstitutionIdentification7ADMN struct {
ClrSysMmbId ClearingSystemMemberIdentification2ADMN `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification7ADMN) MarshalXML ¶
func (v FinancialInstitutionIdentification7ADMN) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification7ADMN) Validate ¶ added in v0.8.0
func (v FinancialInstitutionIdentification7ADMN) Validate() error
type GrpHdr ¶
type GrpHdr struct {
MsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 CreDtTm"`
}
func (GrpHdr) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type GrpHdrTCH ¶
type GrpHdrTCH struct {
MsgId Max35TextTCH `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:admn.006.001.01 CreDtTm"`
}
func (GrpHdrTCH) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type Max35TextTCH ¶
type Max35TextTCH string
func (Max35TextTCH) Validate ¶ added in v0.8.0
func (v Max35TextTCH) Validate() error
type Min11Max11Text ¶
type Min11Max11Text string
func (Min11Max11Text) Validate ¶ added in v0.8.0
func (v Min11Max11Text) Validate() error
type TransactionIndividualStatus3CodeEcho ¶
type TransactionIndividualStatus3CodeEcho string
const TransactionIndividualStatus3CodeEchoActc TransactionIndividualStatus3CodeEcho = "ACTC"
func (TransactionIndividualStatus3CodeEcho) Validate ¶
func (v TransactionIndividualStatus3CodeEcho) Validate() error