Documentation
¶
Overview ¶
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 with prefix 'fi'
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:camt.026.001.07
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 with prefix 'fi'
Index ¶
- type ActiveOrHistoricCurrencyAndAmount
- type ActiveOrHistoricCurrencyAndAmountSimpleType
- type ActiveOrHistoricCurrencyCode
- type BranchAndFinancialInstitutionIdentification6
- type BranchAndFinancialInstitutionIdentification6TCH
- type BranchAndFinancialInstitutionIdentification6TCH2
- type Case5
- type Case5TCH
- type CaseAssignment5
- type CaseAssignment5TCH
- type ClearingSystemMemberIdentification2
- type ClearingSystemMemberIdentification2TCH
- type ClearingSystemMemberIdentification2TCH2
- type DateAndDateTime2Choice
- type DocumentTCH
- type FinancialInstitutionIdentification18
- type FinancialInstitutionIdentification18TCH
- type FinancialInstitutionIdentification18TCH2
- type Max35Text
- type Max35TextTCH
- type Max35TextTCH2
- type Max140Text
- type MissingOrIncorrectInformation3
- type OrigMsgName
- type OrigMsgNameTCH
- type OrigMsgNameTCH2
- type Party40Choice
- type Party40ChoiceTCH
- type Party40ChoiceTCH2
- type PartyIdentification135
- type PartyIdentification135TCH
- type UUIDv4Identifier
- type UnableToApplyIncorrect1
- type UnableToApplyIncorrectInformation4Code
- type UnableToApplyJustification3Choice
- type UnableToApplyMissing1
- type UnableToApplyMissingInformation3Code
- type UnableToApplyV07
- type UnableToApplyV07TCH
- type UnderlyingGroupInformation1
- type UnderlyingGroupInformation1TCH
- type UnderlyingGroupInformation1TCH2
- type UnderlyingPaymentInstruction5
- type UnderlyingPaymentInstruction5TCH
- type UnderlyingPaymentTransaction4
- type UnderlyingPaymentTransaction4TCH
- type UnderlyingTransaction5Choice
- type UnderlyingTransaction5ChoiceTCH
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ActiveOrHistoricCurrencyAndAmount ¶
type ActiveOrHistoricCurrencyAndAmount struct {
Value ActiveOrHistoricCurrencyAndAmountSimpleType `xml:",chardata"`
Ccy ActiveOrHistoricCurrencyCode `xml:"Ccy,attr"`
}
func (ActiveOrHistoricCurrencyAndAmount) Validate ¶
func (v ActiveOrHistoricCurrencyAndAmount) Validate() error
type ActiveOrHistoricCurrencyAndAmountSimpleType ¶
func (ActiveOrHistoricCurrencyAndAmountSimpleType) MarshalText ¶
func (a ActiveOrHistoricCurrencyAndAmountSimpleType) MarshalText() ([]byte, error)
type ActiveOrHistoricCurrencyCode ¶
type ActiveOrHistoricCurrencyCode string
const ActiveOrHistoricCurrencyCodeUsd ActiveOrHistoricCurrencyCode = "USD"
func (ActiveOrHistoricCurrencyCode) Validate ¶
func (v ActiveOrHistoricCurrencyCode) Validate() error
type BranchAndFinancialInstitutionIdentification6 ¶
type BranchAndFinancialInstitutionIdentification6 struct {
FinInstnId FinancialInstitutionIdentification18 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification6) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification6) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification6) Validate ¶
func (v BranchAndFinancialInstitutionIdentification6) Validate() error
type BranchAndFinancialInstitutionIdentification6TCH ¶
type BranchAndFinancialInstitutionIdentification6TCH struct {
FinInstnId FinancialInstitutionIdentification18TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification6TCH) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification6TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification6TCH) Validate ¶
func (v BranchAndFinancialInstitutionIdentification6TCH) Validate() error
type BranchAndFinancialInstitutionIdentification6TCH2 ¶
type BranchAndFinancialInstitutionIdentification6TCH2 struct {
FinInstnId FinancialInstitutionIdentification18TCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification6TCH2) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification6TCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification6TCH2) Validate ¶
func (v BranchAndFinancialInstitutionIdentification6TCH2) Validate() error
type Case5 ¶
type Case5 struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Id"`
Cretr Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Cretr"`
}
func (Case5) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type Case5TCH ¶
type Case5TCH struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Id"`
Cretr Party40ChoiceTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Cretr"`
}
func (Case5TCH) MarshalXML ¶
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type CaseAssignment5 ¶
type CaseAssignment5 struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Id"`
Assgnr Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Assgnr"`
Assgne Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Assgne"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 CreDtTm"`
}
func (CaseAssignment5) MarshalXML ¶
func (v CaseAssignment5) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (CaseAssignment5) Validate ¶
func (v CaseAssignment5) Validate() error
type CaseAssignment5TCH ¶
type CaseAssignment5TCH struct {
Id Max35TextTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Id"`
Assgnr Party40ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Assgnr"`
Assgne Party40ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Assgne"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 CreDtTm"`
}
func (CaseAssignment5TCH) MarshalXML ¶
func (v CaseAssignment5TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (CaseAssignment5TCH) Validate ¶
func (v CaseAssignment5TCH) Validate() error
type ClearingSystemMemberIdentification2 ¶
type ClearingSystemMemberIdentification2 struct {
MmbId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 MmbId"`
}
func (ClearingSystemMemberIdentification2) MarshalXML ¶
func (v ClearingSystemMemberIdentification2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2) Validate ¶
func (v ClearingSystemMemberIdentification2) Validate() error
type ClearingSystemMemberIdentification2TCH ¶
type ClearingSystemMemberIdentification2TCH struct {
MmbId Max35TextTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 MmbId"`
}
func (ClearingSystemMemberIdentification2TCH) MarshalXML ¶
func (v ClearingSystemMemberIdentification2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2TCH) Validate ¶
func (v ClearingSystemMemberIdentification2TCH) Validate() error
type ClearingSystemMemberIdentification2TCH2 ¶
type ClearingSystemMemberIdentification2TCH2 struct {
MmbId Max35TextTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 MmbId"`
}
func (ClearingSystemMemberIdentification2TCH2) MarshalXML ¶
func (v ClearingSystemMemberIdentification2TCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2TCH2) Validate ¶
func (v ClearingSystemMemberIdentification2TCH2) Validate() error
type DateAndDateTime2Choice ¶
type DateAndDateTime2Choice struct {
Dt *rtp.ISODate `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Dt,omitempty"`
DtTm *rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 DtTm,omitempty"`
}
func (DateAndDateTime2Choice) MarshalXML ¶
func (v DateAndDateTime2Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (DateAndDateTime2Choice) Validate ¶
func (v DateAndDateTime2Choice) Validate() error
type DocumentTCH ¶
type DocumentTCH struct {
XMLName xml.Name
UblToApply UnableToApplyV07TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 UblToApply"`
}
func (DocumentTCH) MarshalXML ¶
func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (DocumentTCH) Validate ¶
func (v DocumentTCH) Validate() error
type FinancialInstitutionIdentification18 ¶
type FinancialInstitutionIdentification18 struct {
ClrSysMmbId ClearingSystemMemberIdentification2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification18) MarshalXML ¶
func (v FinancialInstitutionIdentification18) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification18) Validate ¶
func (v FinancialInstitutionIdentification18) Validate() error
type FinancialInstitutionIdentification18TCH ¶
type FinancialInstitutionIdentification18TCH struct {
ClrSysMmbId ClearingSystemMemberIdentification2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification18TCH) MarshalXML ¶
func (v FinancialInstitutionIdentification18TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification18TCH) Validate ¶
func (v FinancialInstitutionIdentification18TCH) Validate() error
type FinancialInstitutionIdentification18TCH2 ¶
type FinancialInstitutionIdentification18TCH2 struct {
ClrSysMmbId ClearingSystemMemberIdentification2TCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification18TCH2) MarshalXML ¶
func (v FinancialInstitutionIdentification18TCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification18TCH2) Validate ¶
func (v FinancialInstitutionIdentification18TCH2) Validate() error
type Max35TextTCH ¶
type Max35TextTCH string
func (Max35TextTCH) Validate ¶
func (v Max35TextTCH) Validate() error
type Max35TextTCH2 ¶
type Max35TextTCH2 string
func (Max35TextTCH2) Validate ¶
func (v Max35TextTCH2) Validate() error
type Max140Text ¶
type Max140Text string
func (Max140Text) Validate ¶
func (v Max140Text) Validate() error
type MissingOrIncorrectInformation3 ¶
type MissingOrIncorrectInformation3 struct {
MssngInf []*UnableToApplyMissing1 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 MssngInf,omitempty"`
IncrrctInf []*UnableToApplyIncorrect1 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 IncrrctInf,omitempty"`
}
func (MissingOrIncorrectInformation3) MarshalXML ¶
func (v MissingOrIncorrectInformation3) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (MissingOrIncorrectInformation3) Validate ¶
func (v MissingOrIncorrectInformation3) Validate() error
type OrigMsgName ¶
type OrigMsgName string
const OrigMsgNamePacs00800106 OrigMsgName = "pacs.008.001.06"
const OrigMsgNamePacs00800108 OrigMsgName = "pacs.008.001.08"
const OrigMsgNamePain01300107 OrigMsgName = "pain.013.001.07"
func (OrigMsgName) Validate ¶
func (v OrigMsgName) Validate() error
type OrigMsgNameTCH ¶
type OrigMsgNameTCH string
const OrigMsgNameTCHPain01300107 OrigMsgNameTCH = "pain.013.001.07"
func (OrigMsgNameTCH) Validate ¶
func (v OrigMsgNameTCH) Validate() error
type OrigMsgNameTCH2 ¶
type OrigMsgNameTCH2 string
const OrigMsgNameTCH2Pacs00800106 OrigMsgNameTCH2 = "pacs.008.001.06"
const OrigMsgNameTCH2Pacs00800108 OrigMsgNameTCH2 = "pacs.008.001.08"
func (OrigMsgNameTCH2) Validate ¶
func (v OrigMsgNameTCH2) Validate() error
type Party40Choice ¶
type Party40Choice struct {
Pty *PartyIdentification135 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Pty,omitempty"`
Agt *BranchAndFinancialInstitutionIdentification6 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Agt,omitempty"`
}
func (Party40Choice) MarshalXML ¶
func (v Party40Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party40Choice) Validate ¶
func (v Party40Choice) Validate() error
type Party40ChoiceTCH ¶
type Party40ChoiceTCH struct {
Agt *BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Agt,omitempty"`
}
func (Party40ChoiceTCH) MarshalXML ¶
func (v Party40ChoiceTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party40ChoiceTCH) Validate ¶
func (v Party40ChoiceTCH) Validate() error
type Party40ChoiceTCH2 ¶
type Party40ChoiceTCH2 struct {
Pty *PartyIdentification135TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Pty,omitempty"`
Agt *BranchAndFinancialInstitutionIdentification6TCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Agt,omitempty"`
}
func (Party40ChoiceTCH2) MarshalXML ¶
func (v Party40ChoiceTCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party40ChoiceTCH2) Validate ¶
func (v Party40ChoiceTCH2) Validate() error
type PartyIdentification135 ¶
type PartyIdentification135 struct {
Nm Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Nm"`
}
func (PartyIdentification135) MarshalXML ¶
func (v PartyIdentification135) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PartyIdentification135) Validate ¶
func (v PartyIdentification135) Validate() error
type PartyIdentification135TCH ¶
type PartyIdentification135TCH struct {
Nm Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Nm"`
}
func (PartyIdentification135TCH) MarshalXML ¶
func (v PartyIdentification135TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PartyIdentification135TCH) Validate ¶
func (v PartyIdentification135TCH) Validate() error
type UUIDv4Identifier ¶
type UUIDv4Identifier string
func (UUIDv4Identifier) Validate ¶
func (v UUIDv4Identifier) Validate() error
type UnableToApplyIncorrect1 ¶
type UnableToApplyIncorrect1 struct {
Cd UnableToApplyIncorrectInformation4Code `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Cd"`
AddtlIncrrctInf *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 AddtlIncrrctInf,omitempty"`
}
func (UnableToApplyIncorrect1) MarshalXML ¶
func (v UnableToApplyIncorrect1) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnableToApplyIncorrect1) Validate ¶
func (v UnableToApplyIncorrect1) Validate() error
type UnableToApplyIncorrectInformation4Code ¶
type UnableToApplyIncorrectInformation4Code string
const UnableToApplyIncorrectInformation4CodeIn01 UnableToApplyIncorrectInformation4Code = "IN01"
const UnableToApplyIncorrectInformation4CodeIn04 UnableToApplyIncorrectInformation4Code = "IN04"
const UnableToApplyIncorrectInformation4CodeIn06 UnableToApplyIncorrectInformation4Code = "IN06"
const UnableToApplyIncorrectInformation4CodeIn15 UnableToApplyIncorrectInformation4Code = "IN15"
const UnableToApplyIncorrectInformation4CodeIn19 UnableToApplyIncorrectInformation4Code = "IN19"
const UnableToApplyIncorrectInformation4CodeIn38 UnableToApplyIncorrectInformation4Code = "IN38"
const UnableToApplyIncorrectInformation4CodeIn39 UnableToApplyIncorrectInformation4Code = "IN39"
const UnableToApplyIncorrectInformation4CodeMm20 UnableToApplyIncorrectInformation4Code = "MM20"
const UnableToApplyIncorrectInformation4CodeMm21 UnableToApplyIncorrectInformation4Code = "MM21"
const UnableToApplyIncorrectInformation4CodeNarr UnableToApplyIncorrectInformation4Code = "NARR"
func (UnableToApplyIncorrectInformation4Code) Validate ¶
func (v UnableToApplyIncorrectInformation4Code) Validate() error
type UnableToApplyJustification3Choice ¶
type UnableToApplyJustification3Choice struct {
MssngOrIncrrctInf *MissingOrIncorrectInformation3 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 MssngOrIncrrctInf,omitempty"`
}
func (UnableToApplyJustification3Choice) MarshalXML ¶
func (v UnableToApplyJustification3Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnableToApplyJustification3Choice) Validate ¶
func (v UnableToApplyJustification3Choice) Validate() error
type UnableToApplyMissing1 ¶
type UnableToApplyMissing1 struct {
Cd UnableToApplyMissingInformation3Code `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Cd"`
AddtlMssngInf *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 AddtlMssngInf,omitempty"`
}
func (UnableToApplyMissing1) MarshalXML ¶
func (v UnableToApplyMissing1) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnableToApplyMissing1) Validate ¶
func (v UnableToApplyMissing1) Validate() error
type UnableToApplyMissingInformation3Code ¶
type UnableToApplyMissingInformation3Code string
const UnableToApplyMissingInformation3CodeMs01 UnableToApplyMissingInformation3Code = "MS01"
const UnableToApplyMissingInformation3CodeNarr UnableToApplyMissingInformation3Code = "NARR"
func (UnableToApplyMissingInformation3Code) Validate ¶
func (v UnableToApplyMissingInformation3Code) Validate() error
type UnableToApplyV07 ¶
type UnableToApplyV07 struct {
Assgnmt CaseAssignment5 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Assgnmt"`
Case Case5 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Case"`
Undrlyg UnderlyingTransaction5Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Undrlyg"`
Justfn UnableToApplyJustification3Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Justfn"`
}
func (UnableToApplyV07) MarshalXML ¶
func (v UnableToApplyV07) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnableToApplyV07) Validate ¶
func (v UnableToApplyV07) Validate() error
type UnableToApplyV07TCH ¶
type UnableToApplyV07TCH struct {
Assgnmt CaseAssignment5TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Assgnmt"`
Case Case5TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Case"`
Undrlyg UnderlyingTransaction5ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Undrlyg"`
Justfn UnableToApplyJustification3Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Justfn"`
}
func (UnableToApplyV07TCH) MarshalXML ¶
func (v UnableToApplyV07TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnableToApplyV07TCH) Validate ¶
func (v UnableToApplyV07TCH) Validate() error
type UnderlyingGroupInformation1 ¶
type UnderlyingGroupInformation1 struct {
OrgnlMsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlMsgId"`
OrgnlMsgNmId OrigMsgName `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlMsgNmId"`
OrgnlCreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlCreDtTm"`
}
func (UnderlyingGroupInformation1) MarshalXML ¶
func (v UnderlyingGroupInformation1) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingGroupInformation1) Validate ¶
func (v UnderlyingGroupInformation1) Validate() error
type UnderlyingGroupInformation1TCH ¶
type UnderlyingGroupInformation1TCH struct {
OrgnlMsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlMsgId"`
OrgnlMsgNmId OrigMsgNameTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlMsgNmId"`
OrgnlCreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlCreDtTm"`
}
func (UnderlyingGroupInformation1TCH) MarshalXML ¶
func (v UnderlyingGroupInformation1TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingGroupInformation1TCH) Validate ¶
func (v UnderlyingGroupInformation1TCH) Validate() error
type UnderlyingGroupInformation1TCH2 ¶
type UnderlyingGroupInformation1TCH2 struct {
OrgnlMsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlMsgId"`
OrgnlMsgNmId OrigMsgNameTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlMsgNmId"`
OrgnlCreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlCreDtTm"`
}
func (UnderlyingGroupInformation1TCH2) MarshalXML ¶
func (v UnderlyingGroupInformation1TCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingGroupInformation1TCH2) Validate ¶
func (v UnderlyingGroupInformation1TCH2) Validate() error
type UnderlyingPaymentInstruction5 ¶
type UnderlyingPaymentInstruction5 struct {
OrgnlGrpInf UnderlyingGroupInformation1 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlGrpInf"`
OrgnlPmtInfId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlPmtInfId"`
OrgnlEndToEndId *Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlEndToEndId,omitempty"`
OrgnlUETR *UUIDv4Identifier `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlUETR,omitempty"`
OrgnlInstdAmt ActiveOrHistoricCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlInstdAmt"`
ReqdExctnDt DateAndDateTime2Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 ReqdExctnDt"`
}
func (UnderlyingPaymentInstruction5) MarshalXML ¶
func (v UnderlyingPaymentInstruction5) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingPaymentInstruction5) Validate ¶
func (v UnderlyingPaymentInstruction5) Validate() error
type UnderlyingPaymentInstruction5TCH ¶
type UnderlyingPaymentInstruction5TCH struct {
OrgnlGrpInf UnderlyingGroupInformation1TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlGrpInf"`
OrgnlPmtInfId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlPmtInfId"`
OrgnlEndToEndId *Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlEndToEndId,omitempty"`
OrgnlUETR *UUIDv4Identifier `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlUETR,omitempty"`
OrgnlInstdAmt ActiveOrHistoricCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlInstdAmt"`
ReqdExctnDt DateAndDateTime2Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 ReqdExctnDt"`
}
func (UnderlyingPaymentInstruction5TCH) MarshalXML ¶
func (v UnderlyingPaymentInstruction5TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingPaymentInstruction5TCH) Validate ¶
func (v UnderlyingPaymentInstruction5TCH) Validate() error
type UnderlyingPaymentTransaction4 ¶
type UnderlyingPaymentTransaction4 struct {
OrgnlGrpInf UnderlyingGroupInformation1 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlGrpInf"`
OrgnlInstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlInstrId"`
OrgnlEndToEndId *Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlEndToEndId,omitempty"`
OrgnlTxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlTxId"`
OrgnlUETR *UUIDv4Identifier `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlUETR,omitempty"`
OrgnlIntrBkSttlmAmt ActiveOrHistoricCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlIntrBkSttlmAmt"`
OrgnlIntrBkSttlmDt rtp.ISODate `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlIntrBkSttlmDt"`
}
func (UnderlyingPaymentTransaction4) MarshalXML ¶
func (v UnderlyingPaymentTransaction4) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingPaymentTransaction4) Validate ¶
func (v UnderlyingPaymentTransaction4) Validate() error
type UnderlyingPaymentTransaction4TCH ¶
type UnderlyingPaymentTransaction4TCH struct {
OrgnlGrpInf UnderlyingGroupInformation1TCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlGrpInf"`
OrgnlInstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlInstrId"`
OrgnlEndToEndId *Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlEndToEndId,omitempty"`
OrgnlTxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlTxId"`
OrgnlUETR *UUIDv4Identifier `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlUETR,omitempty"`
OrgnlIntrBkSttlmAmt ActiveOrHistoricCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlIntrBkSttlmAmt"`
OrgnlIntrBkSttlmDt rtp.ISODate `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 OrgnlIntrBkSttlmDt"`
}
func (UnderlyingPaymentTransaction4TCH) MarshalXML ¶
func (v UnderlyingPaymentTransaction4TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingPaymentTransaction4TCH) Validate ¶
func (v UnderlyingPaymentTransaction4TCH) Validate() error
type UnderlyingTransaction5Choice ¶
type UnderlyingTransaction5Choice struct {
Initn *UnderlyingPaymentInstruction5 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Initn,omitempty"`
IntrBk *UnderlyingPaymentTransaction4 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 IntrBk,omitempty"`
}
func (UnderlyingTransaction5Choice) MarshalXML ¶
func (v UnderlyingTransaction5Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingTransaction5Choice) Validate ¶
func (v UnderlyingTransaction5Choice) Validate() error
type UnderlyingTransaction5ChoiceTCH ¶
type UnderlyingTransaction5ChoiceTCH struct {
Initn *UnderlyingPaymentInstruction5TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 Initn,omitempty"`
IntrBk *UnderlyingPaymentTransaction4TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.026.001.07 IntrBk,omitempty"`
}
func (UnderlyingTransaction5ChoiceTCH) MarshalXML ¶
func (v UnderlyingTransaction5ChoiceTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (UnderlyingTransaction5ChoiceTCH) Validate ¶
func (v UnderlyingTransaction5ChoiceTCH) Validate() error