Documentation
¶
Overview ¶
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 with prefix 'ac'
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:camt.035.001.05
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 with prefix 'ac'
Index ¶
- type BranchAndFinancialInstitutionIdentification6
- type BranchAndFinancialInstitutionIdentification6TCH
- type Case5
- type Case5TCH
- type CaseAssignment5
- type CaseAssignment5TCH
- type ClearingSystemMemberIdentification2
- type ClearingSystemMemberIdentification2TCH
- type DocumentTCH
- type FinancialInstitutionIdentification18
- type FinancialInstitutionIdentification18TCH
- type Max35Text
- type Max35TextTCH
- type Max35TextTCH2
- type Max35TextTCH3
- type Max140Text
- type Party40Choice
- type Party40ChoiceTCH
- type Party40ChoiceTCH2
- type PartyIdentification135
- type PartyIdentification135TCH
- type ProprietaryData6Reduced
- type ProprietaryData6ReducedTCH
- type ProprietaryData7TCH
- type ProprietaryData7TCHTCH
- type ProprietaryFormatInvestigationV05
- type ProprietaryFormatInvestigationV05TCH
- type TransactionReferences8Reduced
- type TransactionReferences8ReducedTCH
- type UUIDv4Identifier
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BranchAndFinancialInstitutionIdentification6 ¶
type BranchAndFinancialInstitutionIdentification6 struct {
FinInstnId FinancialInstitutionIdentification18 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification6) MarshalXML ¶ added in v0.7.0
func (v BranchAndFinancialInstitutionIdentification6) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification6) Validate ¶ added in v0.8.0
func (v BranchAndFinancialInstitutionIdentification6) Validate() error
type BranchAndFinancialInstitutionIdentification6TCH ¶ added in v0.7.0
type BranchAndFinancialInstitutionIdentification6TCH struct {
FinInstnId FinancialInstitutionIdentification18TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification6TCH) MarshalXML ¶ added in v0.7.0
func (v BranchAndFinancialInstitutionIdentification6TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification6TCH) Validate ¶ added in v0.8.0
func (v BranchAndFinancialInstitutionIdentification6TCH) Validate() error
type Case5 ¶
type Case5 struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Id"`
Cretr Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Cretr"`
}
func (Case5) MarshalXML ¶ added in v0.7.0
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type Case5TCH ¶ added in v0.7.0
type Case5TCH struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Id"`
Cretr Party40ChoiceTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Cretr"`
}
func (Case5TCH) MarshalXML ¶ added in v0.7.0
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
type CaseAssignment5 ¶
type CaseAssignment5 struct {
Id Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Id"`
Assgnr Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Assgnr"`
Assgne Party40Choice `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Assgne"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 CreDtTm"`
}
func (CaseAssignment5) MarshalXML ¶ added in v0.7.0
func (v CaseAssignment5) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (CaseAssignment5) Validate ¶ added in v0.8.0
func (v CaseAssignment5) Validate() error
type CaseAssignment5TCH ¶ added in v0.7.0
type CaseAssignment5TCH struct {
Id Max35TextTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Id"`
Assgnr Party40ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Assgnr"`
Assgne Party40ChoiceTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Assgne"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 CreDtTm"`
}
func (CaseAssignment5TCH) MarshalXML ¶ added in v0.7.0
func (v CaseAssignment5TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (CaseAssignment5TCH) Validate ¶ added in v0.8.0
func (v CaseAssignment5TCH) Validate() error
type ClearingSystemMemberIdentification2 ¶
type ClearingSystemMemberIdentification2 struct {
MmbId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 MmbId"`
}
func (ClearingSystemMemberIdentification2) MarshalXML ¶ added in v0.7.0
func (v ClearingSystemMemberIdentification2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2) Validate ¶ added in v0.8.0
func (v ClearingSystemMemberIdentification2) Validate() error
type ClearingSystemMemberIdentification2TCH ¶ added in v0.7.0
type ClearingSystemMemberIdentification2TCH struct {
MmbId Max35TextTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 MmbId"`
}
func (ClearingSystemMemberIdentification2TCH) MarshalXML ¶ added in v0.7.0
func (v ClearingSystemMemberIdentification2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2TCH) Validate ¶ added in v0.8.0
func (v ClearingSystemMemberIdentification2TCH) Validate() error
type DocumentTCH ¶ added in v0.7.0
type DocumentTCH struct {
XMLName xml.Name
PrtryFrmtInvstgtn ProprietaryFormatInvestigationV05TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 PrtryFrmtInvstgtn"`
}
func (DocumentTCH) MarshalXML ¶ added in v0.7.0
func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (DocumentTCH) Validate ¶ added in v0.8.0
func (v DocumentTCH) Validate() error
type FinancialInstitutionIdentification18 ¶
type FinancialInstitutionIdentification18 struct {
ClrSysMmbId ClearingSystemMemberIdentification2 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification18) MarshalXML ¶ added in v0.7.0
func (v FinancialInstitutionIdentification18) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification18) Validate ¶ added in v0.8.0
func (v FinancialInstitutionIdentification18) Validate() error
type FinancialInstitutionIdentification18TCH ¶ added in v0.7.0
type FinancialInstitutionIdentification18TCH struct {
ClrSysMmbId ClearingSystemMemberIdentification2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification18TCH) MarshalXML ¶ added in v0.7.0
func (v FinancialInstitutionIdentification18TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification18TCH) Validate ¶ added in v0.8.0
func (v FinancialInstitutionIdentification18TCH) Validate() error
type Max35TextTCH ¶ added in v0.7.0
type Max35TextTCH string
func (Max35TextTCH) Validate ¶ added in v0.8.0
func (v Max35TextTCH) Validate() error
type Max35TextTCH2 ¶ added in v0.7.0
type Max35TextTCH2 string
func (Max35TextTCH2) Validate ¶ added in v0.8.0
func (v Max35TextTCH2) Validate() error
type Max35TextTCH3 ¶ added in v0.7.0
type Max35TextTCH3 string
const Max35TextTCH3Ack Max35TextTCH3 = "ACK"
const Max35TextTCH3Acwp Max35TextTCH3 = "ACWP"
func (Max35TextTCH3) Validate ¶ added in v0.8.0
func (v Max35TextTCH3) Validate() error
type Max140Text ¶
type Max140Text string
func (Max140Text) Validate ¶ added in v0.8.0
func (v Max140Text) Validate() error
type Party40Choice ¶
type Party40Choice struct {
Pty *PartyIdentification135 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Pty,omitempty"`
Agt *BranchAndFinancialInstitutionIdentification6 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Agt,omitempty"`
}
func (Party40Choice) MarshalXML ¶ added in v0.7.0
func (v Party40Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party40Choice) Validate ¶ added in v0.8.0
func (v Party40Choice) Validate() error
type Party40ChoiceTCH ¶ added in v0.7.0
type Party40ChoiceTCH struct {
Agt *BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Agt,omitempty"`
}
func (Party40ChoiceTCH) MarshalXML ¶ added in v0.7.0
func (v Party40ChoiceTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party40ChoiceTCH) Validate ¶ added in v0.8.0
func (v Party40ChoiceTCH) Validate() error
type Party40ChoiceTCH2 ¶ added in v0.7.0
type Party40ChoiceTCH2 struct {
Pty *PartyIdentification135TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Pty,omitempty"`
Agt *BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Agt,omitempty"`
}
func (Party40ChoiceTCH2) MarshalXML ¶ added in v0.7.0
func (v Party40ChoiceTCH2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (Party40ChoiceTCH2) Validate ¶ added in v0.8.0
func (v Party40ChoiceTCH2) Validate() error
type PartyIdentification135 ¶
type PartyIdentification135 struct {
Nm Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Nm"`
}
func (PartyIdentification135) MarshalXML ¶ added in v0.7.0
func (v PartyIdentification135) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PartyIdentification135) Validate ¶ added in v0.8.0
func (v PartyIdentification135) Validate() error
type PartyIdentification135TCH ¶ added in v0.7.0
type PartyIdentification135TCH struct {
Nm Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Nm"`
}
func (PartyIdentification135TCH) MarshalXML ¶ added in v0.7.0
func (v PartyIdentification135TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PartyIdentification135TCH) Validate ¶ added in v0.8.0
func (v PartyIdentification135TCH) Validate() error
type ProprietaryData6Reduced ¶ added in v0.7.0
type ProprietaryData6Reduced struct {
Ustrd *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Ustrd,omitempty"`
OrigRefs TransactionReferences8Reduced `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 OrigRefs"`
}
func (ProprietaryData6Reduced) MarshalXML ¶ added in v0.7.0
func (v ProprietaryData6Reduced) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ProprietaryData6Reduced) Validate ¶ added in v0.8.0
func (v ProprietaryData6Reduced) Validate() error
type ProprietaryData6ReducedTCH ¶ added in v0.7.0
type ProprietaryData6ReducedTCH struct {
Ustrd *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Ustrd,omitempty"`
OrigRefs TransactionReferences8ReducedTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 OrigRefs"`
}
func (ProprietaryData6ReducedTCH) MarshalXML ¶ added in v0.7.0
func (v ProprietaryData6ReducedTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ProprietaryData6ReducedTCH) Validate ¶ added in v0.8.0
func (v ProprietaryData6ReducedTCH) Validate() error
type ProprietaryData7TCH ¶
type ProprietaryData7TCH struct {
Tp Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Tp"`
Data ProprietaryData6Reduced `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Data"`
}
func (ProprietaryData7TCH) MarshalXML ¶ added in v0.7.0
func (v ProprietaryData7TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ProprietaryData7TCH) Validate ¶ added in v0.8.0
func (v ProprietaryData7TCH) Validate() error
type ProprietaryData7TCHTCH ¶ added in v0.7.0
type ProprietaryData7TCHTCH struct {
Tp Max35TextTCH3 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Tp"`
Data ProprietaryData6ReducedTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Data"`
}
func (ProprietaryData7TCHTCH) MarshalXML ¶ added in v0.7.0
func (v ProprietaryData7TCHTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ProprietaryData7TCHTCH) Validate ¶ added in v0.8.0
func (v ProprietaryData7TCHTCH) Validate() error
type ProprietaryFormatInvestigationV05 ¶
type ProprietaryFormatInvestigationV05 struct {
Assgnmt CaseAssignment5 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Assgnmt"`
Case Case5 `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Case"`
PrtryData ProprietaryData7TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 PrtryData"`
}
func (ProprietaryFormatInvestigationV05) MarshalXML ¶ added in v0.7.0
func (v ProprietaryFormatInvestigationV05) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ProprietaryFormatInvestigationV05) Validate ¶
func (v ProprietaryFormatInvestigationV05) Validate() error
type ProprietaryFormatInvestigationV05TCH ¶ added in v0.7.0
type ProprietaryFormatInvestigationV05TCH struct {
Assgnmt CaseAssignment5TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Assgnmt"`
Case Case5TCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 Case"`
PrtryData ProprietaryData7TCHTCH `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 PrtryData"`
}
func (ProprietaryFormatInvestigationV05TCH) MarshalXML ¶ added in v0.7.0
func (v ProprietaryFormatInvestigationV05TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ProprietaryFormatInvestigationV05TCH) Validate ¶ added in v0.8.0
func (v ProprietaryFormatInvestigationV05TCH) Validate() error
type TransactionReferences8Reduced ¶ added in v0.7.0
type TransactionReferences8Reduced struct {
InstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 InstrId"`
EndToEndId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 EndToEndId"`
TxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 TxId"`
UETR *UUIDv4Identifier `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 UETR,omitempty"`
}
func (TransactionReferences8Reduced) MarshalXML ¶ added in v0.7.0
func (v TransactionReferences8Reduced) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (TransactionReferences8Reduced) Validate ¶ added in v0.8.0
func (v TransactionReferences8Reduced) Validate() error
type TransactionReferences8ReducedTCH ¶ added in v0.7.0
type TransactionReferences8ReducedTCH struct {
InstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 InstrId"`
EndToEndId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 EndToEndId"`
TxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 TxId"`
UETR *UUIDv4Identifier `xml:"urn:iso:std:iso:20022:tech:xsd:camt.035.001.05 UETR,omitempty"`
}
func (TransactionReferences8ReducedTCH) MarshalXML ¶ added in v0.7.0
func (v TransactionReferences8ReducedTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (TransactionReferences8ReducedTCH) Validate ¶ added in v0.8.0
func (v TransactionReferences8ReducedTCH) Validate() error
type UUIDv4Identifier ¶ added in v0.8.0
type UUIDv4Identifier string
func (UUIDv4Identifier) Validate ¶ added in v0.8.0
func (v UUIDv4Identifier) Validate() error