Documentation
¶
Overview ¶
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 with prefix 'c9'
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Validations for urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT. Models for urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 with prefix 'c9'
Index ¶
- type AccountIdentification4Choice
- type ActiveCurrencyAndAmount
- type ActiveCurrencyAndAmountSimpleType
- type ActiveCurrencyCode
- type BranchAndFinancialInstitutionIdentification6
- type BranchAndFinancialInstitutionIdentification6TCH
- type CashAccount38
- type ClearingSystemIdentification3Choice
- type ClearingSystemMemberIdentification2
- type ClearingSystemMemberIdentification2TCH
- type CreditTransferTransaction36
- type CreditTransferTransaction36TCH
- type DocumentTCH
- type ExternalCashClearingSystem1Code
- type ExternalServiceLevel1Code
- type FinancialInstitutionCreditTransferV08
- type FinancialInstitutionCreditTransferV08TCH
- type FinancialInstitutionIdentification18
- type FinancialInstitutionIdentification18TCH
- type GenericAccountIdentification1
- type GroupHeader93
- type GroupHeader93TCH
- type Max1NumericText
- type Max34Text
- type Max35Text
- type Max35TextTCH
- type Max35TextTCH2
- type Max35TextTCH3
- type Max140Text
- type PaymentIdentification7
- type PaymentIdentification7TCH
- type PaymentTypeInformation28
- type PaymentTypeInformation28TCH
- type RemittanceInformation2
- type RemittanceInformation2TCH
- type ServiceLevel8Choice
- type SettlementInstruction7
- type SettlementInstruction7TCH
- type SettlementMethod1Code
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountIdentification4Choice ¶
type AccountIdentification4Choice struct {
Othr *GenericAccountIdentification1 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Othr,omitempty"`
}
func (AccountIdentification4Choice) MarshalXML ¶
func (v AccountIdentification4Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (AccountIdentification4Choice) Validate ¶
func (v AccountIdentification4Choice) Validate() error
type ActiveCurrencyAndAmount ¶
type ActiveCurrencyAndAmount struct {
Value ActiveCurrencyAndAmountSimpleType `xml:",chardata"`
Ccy ActiveCurrencyCode `xml:"Ccy,attr"`
}
func (ActiveCurrencyAndAmount) Validate ¶
func (v ActiveCurrencyAndAmount) Validate() error
type ActiveCurrencyAndAmountSimpleType ¶
func (ActiveCurrencyAndAmountSimpleType) MarshalText ¶
func (a ActiveCurrencyAndAmountSimpleType) MarshalText() ([]byte, error)
type ActiveCurrencyCode ¶
type ActiveCurrencyCode string
const ActiveCurrencyCodeUsd ActiveCurrencyCode = "USD"
func (ActiveCurrencyCode) Validate ¶
func (v ActiveCurrencyCode) Validate() error
type BranchAndFinancialInstitutionIdentification6 ¶
type BranchAndFinancialInstitutionIdentification6 struct {
FinInstnId FinancialInstitutionIdentification18 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification6) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification6) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification6) Validate ¶
func (v BranchAndFinancialInstitutionIdentification6) Validate() error
type BranchAndFinancialInstitutionIdentification6TCH ¶
type BranchAndFinancialInstitutionIdentification6TCH struct {
FinInstnId FinancialInstitutionIdentification18TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 FinInstnId"`
}
func (BranchAndFinancialInstitutionIdentification6TCH) MarshalXML ¶
func (v BranchAndFinancialInstitutionIdentification6TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (BranchAndFinancialInstitutionIdentification6TCH) Validate ¶
func (v BranchAndFinancialInstitutionIdentification6TCH) Validate() error
type CashAccount38 ¶
type CashAccount38 struct {
Id AccountIdentification4Choice `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Id"`
}
func (CashAccount38) MarshalXML ¶
func (v CashAccount38) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (CashAccount38) Validate ¶
func (v CashAccount38) Validate() error
type ClearingSystemIdentification3Choice ¶
type ClearingSystemIdentification3Choice struct {
Cd *ExternalCashClearingSystem1Code `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Cd,omitempty"`
}
func (ClearingSystemIdentification3Choice) MarshalXML ¶
func (v ClearingSystemIdentification3Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemIdentification3Choice) Validate ¶
func (v ClearingSystemIdentification3Choice) Validate() error
type ClearingSystemMemberIdentification2 ¶
type ClearingSystemMemberIdentification2 struct {
MmbId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 MmbId"`
}
func (ClearingSystemMemberIdentification2) MarshalXML ¶
func (v ClearingSystemMemberIdentification2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2) Validate ¶
func (v ClearingSystemMemberIdentification2) Validate() error
type ClearingSystemMemberIdentification2TCH ¶
type ClearingSystemMemberIdentification2TCH struct {
MmbId Max35TextTCH3 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 MmbId"`
}
func (ClearingSystemMemberIdentification2TCH) MarshalXML ¶
func (v ClearingSystemMemberIdentification2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ClearingSystemMemberIdentification2TCH) Validate ¶
func (v ClearingSystemMemberIdentification2TCH) Validate() error
type CreditTransferTransaction36 ¶
type CreditTransferTransaction36 struct {
PmtId PaymentIdentification7 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 PmtId"`
PmtTpInf PaymentTypeInformation28 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 PmtTpInf"`
IntrBkSttlmAmt ActiveCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 IntrBkSttlmAmt"`
InstgAgt BranchAndFinancialInstitutionIdentification6 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 InstgAgt"`
InstdAgt BranchAndFinancialInstitutionIdentification6 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 InstdAgt"`
Dbtr BranchAndFinancialInstitutionIdentification6 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Dbtr"`
DbtrAcct *CashAccount38 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 DbtrAcct,omitempty"`
Cdtr BranchAndFinancialInstitutionIdentification6 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Cdtr"`
CdtrAcct CashAccount38 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 CdtrAcct"`
RmtInf *RemittanceInformation2 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 RmtInf,omitempty"`
}
func (CreditTransferTransaction36) MarshalXML ¶
func (v CreditTransferTransaction36) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (CreditTransferTransaction36) Validate ¶
func (v CreditTransferTransaction36) Validate() error
type CreditTransferTransaction36TCH ¶
type CreditTransferTransaction36TCH struct {
PmtId PaymentIdentification7TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 PmtId"`
PmtTpInf PaymentTypeInformation28TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 PmtTpInf"`
IntrBkSttlmAmt ActiveCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 IntrBkSttlmAmt"`
InstgAgt BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 InstgAgt"`
InstdAgt BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 InstdAgt"`
Dbtr BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Dbtr"`
DbtrAcct *CashAccount38 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 DbtrAcct,omitempty"`
Cdtr BranchAndFinancialInstitutionIdentification6TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Cdtr"`
CdtrAcct CashAccount38 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 CdtrAcct"`
RmtInf *RemittanceInformation2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 RmtInf,omitempty"`
}
func (CreditTransferTransaction36TCH) MarshalXML ¶
func (v CreditTransferTransaction36TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (CreditTransferTransaction36TCH) Validate ¶
func (v CreditTransferTransaction36TCH) Validate() error
type DocumentTCH ¶
type DocumentTCH struct {
XMLName xml.Name
FICdtTrf FinancialInstitutionCreditTransferV08TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 FICdtTrf"`
}
func (DocumentTCH) MarshalXML ¶
func (v DocumentTCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (DocumentTCH) Validate ¶
func (v DocumentTCH) Validate() error
type ExternalCashClearingSystem1Code ¶
type ExternalCashClearingSystem1Code string
const ExternalCashClearingSystem1CodeTch ExternalCashClearingSystem1Code = "TCH"
func (ExternalCashClearingSystem1Code) Validate ¶
func (v ExternalCashClearingSystem1Code) Validate() error
type ExternalServiceLevel1Code ¶
type ExternalServiceLevel1Code string
const ExternalServiceLevel1CodeSdva ExternalServiceLevel1Code = "SDVA"
func (ExternalServiceLevel1Code) Validate ¶
func (v ExternalServiceLevel1Code) Validate() error
type FinancialInstitutionCreditTransferV08 ¶
type FinancialInstitutionCreditTransferV08 struct {
GrpHdr GroupHeader93 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 GrpHdr"`
CdtTrfTxInf CreditTransferTransaction36 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 CdtTrfTxInf"`
}
func (FinancialInstitutionCreditTransferV08) MarshalXML ¶
func (v FinancialInstitutionCreditTransferV08) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionCreditTransferV08) Validate ¶
func (v FinancialInstitutionCreditTransferV08) Validate() error
type FinancialInstitutionCreditTransferV08TCH ¶
type FinancialInstitutionCreditTransferV08TCH struct {
GrpHdr GroupHeader93TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 GrpHdr"`
CdtTrfTxInf CreditTransferTransaction36TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 CdtTrfTxInf"`
}
func (FinancialInstitutionCreditTransferV08TCH) MarshalXML ¶
func (v FinancialInstitutionCreditTransferV08TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionCreditTransferV08TCH) Validate ¶
func (v FinancialInstitutionCreditTransferV08TCH) Validate() error
type FinancialInstitutionIdentification18 ¶
type FinancialInstitutionIdentification18 struct {
ClrSysMmbId ClearingSystemMemberIdentification2 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification18) MarshalXML ¶
func (v FinancialInstitutionIdentification18) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification18) Validate ¶
func (v FinancialInstitutionIdentification18) Validate() error
type FinancialInstitutionIdentification18TCH ¶
type FinancialInstitutionIdentification18TCH struct {
ClrSysMmbId ClearingSystemMemberIdentification2TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 ClrSysMmbId"`
}
func (FinancialInstitutionIdentification18TCH) MarshalXML ¶
func (v FinancialInstitutionIdentification18TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (FinancialInstitutionIdentification18TCH) Validate ¶
func (v FinancialInstitutionIdentification18TCH) Validate() error
type GenericAccountIdentification1 ¶
type GenericAccountIdentification1 struct {
Id Max34Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Id"`
}
func (GenericAccountIdentification1) MarshalXML ¶
func (v GenericAccountIdentification1) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (GenericAccountIdentification1) Validate ¶
func (v GenericAccountIdentification1) Validate() error
type GroupHeader93 ¶
type GroupHeader93 struct {
MsgId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 CreDtTm"`
NbOfTxs Max1NumericText `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 NbOfTxs"`
TtlIntrBkSttlmAmt ActiveCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 TtlIntrBkSttlmAmt"`
IntrBkSttlmDt rtp.ISODate `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 IntrBkSttlmDt"`
SttlmInf SettlementInstruction7 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 SttlmInf"`
}
func (GroupHeader93) MarshalXML ¶
func (v GroupHeader93) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (GroupHeader93) Validate ¶
func (v GroupHeader93) Validate() error
type GroupHeader93TCH ¶
type GroupHeader93TCH struct {
MsgId Max35TextTCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 MsgId"`
CreDtTm rtp.ISODateTime `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 CreDtTm"`
NbOfTxs Max1NumericText `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 NbOfTxs"`
TtlIntrBkSttlmAmt ActiveCurrencyAndAmount `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 TtlIntrBkSttlmAmt"`
IntrBkSttlmDt rtp.ISODate `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 IntrBkSttlmDt"`
SttlmInf SettlementInstruction7TCH `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 SttlmInf"`
}
func (GroupHeader93TCH) MarshalXML ¶
func (v GroupHeader93TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (GroupHeader93TCH) Validate ¶
func (v GroupHeader93TCH) Validate() error
type Max1NumericText ¶
type Max1NumericText string
func (Max1NumericText) Validate ¶
func (v Max1NumericText) Validate() error
type Max35TextTCH ¶
type Max35TextTCH string
func (Max35TextTCH) Validate ¶
func (v Max35TextTCH) Validate() error
type Max35TextTCH2 ¶
type Max35TextTCH2 string
func (Max35TextTCH2) Validate ¶
func (v Max35TextTCH2) Validate() error
type Max35TextTCH3 ¶
type Max35TextTCH3 string
func (Max35TextTCH3) Validate ¶
func (v Max35TextTCH3) Validate() error
type Max140Text ¶
type Max140Text string
func (Max140Text) Validate ¶
func (v Max140Text) Validate() error
type PaymentIdentification7 ¶
type PaymentIdentification7 struct {
InstrId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 InstrId"`
EndToEndId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 EndToEndId"`
TxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 TxId"`
ClrSysRef *Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 ClrSysRef,omitempty"`
}
func (PaymentIdentification7) MarshalXML ¶
func (v PaymentIdentification7) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PaymentIdentification7) Validate ¶
func (v PaymentIdentification7) Validate() error
type PaymentIdentification7TCH ¶
type PaymentIdentification7TCH struct {
InstrId Max35TextTCH2 `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 InstrId"`
EndToEndId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 EndToEndId"`
TxId Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 TxId"`
ClrSysRef *Max35Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 ClrSysRef,omitempty"`
}
func (PaymentIdentification7TCH) MarshalXML ¶
func (v PaymentIdentification7TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PaymentIdentification7TCH) Validate ¶
func (v PaymentIdentification7TCH) Validate() error
type PaymentTypeInformation28 ¶
type PaymentTypeInformation28 struct {
SvcLvl ServiceLevel8Choice `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 SvcLvl"`
}
func (PaymentTypeInformation28) MarshalXML ¶
func (v PaymentTypeInformation28) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PaymentTypeInformation28) Validate ¶
func (v PaymentTypeInformation28) Validate() error
type PaymentTypeInformation28TCH ¶
type PaymentTypeInformation28TCH struct {
SvcLvl ServiceLevel8Choice `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 SvcLvl"`
}
func (PaymentTypeInformation28TCH) MarshalXML ¶
func (v PaymentTypeInformation28TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (PaymentTypeInformation28TCH) Validate ¶
func (v PaymentTypeInformation28TCH) Validate() error
type RemittanceInformation2 ¶
type RemittanceInformation2 struct {
Ustrd *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Ustrd,omitempty"`
}
func (RemittanceInformation2) MarshalXML ¶
func (v RemittanceInformation2) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (RemittanceInformation2) Validate ¶
func (v RemittanceInformation2) Validate() error
type RemittanceInformation2TCH ¶
type RemittanceInformation2TCH struct {
Ustrd *Max140Text `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Ustrd,omitempty"`
}
func (RemittanceInformation2TCH) MarshalXML ¶
func (v RemittanceInformation2TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (RemittanceInformation2TCH) Validate ¶
func (v RemittanceInformation2TCH) Validate() error
type ServiceLevel8Choice ¶
type ServiceLevel8Choice struct {
Cd *ExternalServiceLevel1Code `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 Cd,omitempty"`
}
func (ServiceLevel8Choice) MarshalXML ¶
func (v ServiceLevel8Choice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (ServiceLevel8Choice) Validate ¶
func (v ServiceLevel8Choice) Validate() error
type SettlementInstruction7 ¶
type SettlementInstruction7 struct {
SttlmMtd SettlementMethod1Code `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 SttlmMtd"`
ClrSys ClearingSystemIdentification3Choice `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 ClrSys"`
}
func (SettlementInstruction7) MarshalXML ¶
func (v SettlementInstruction7) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (SettlementInstruction7) Validate ¶
func (v SettlementInstruction7) Validate() error
type SettlementInstruction7TCH ¶
type SettlementInstruction7TCH struct {
SttlmMtd SettlementMethod1Code `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 SttlmMtd"`
ClrSys ClearingSystemIdentification3Choice `xml:"urn:iso:std:iso:20022:tech:xsd:pacs.009.001.08 ClrSys"`
}
func (SettlementInstruction7TCH) MarshalXML ¶
func (v SettlementInstruction7TCH) MarshalXML(e *xml.Encoder, start xml.StartElement) error
MarshalXML is a custom marshaller that allows us to manipulate the XML tag in order to use the proper namespace prefix
func (SettlementInstruction7TCH) Validate ¶
func (v SettlementInstruction7TCH) Validate() error
type SettlementMethod1Code ¶
type SettlementMethod1Code string
const SettlementMethod1CodeClrg SettlementMethod1Code = "CLRG"
func (SettlementMethod1Code) Validate ¶
func (v SettlementMethod1Code) Validate() error